# $Id: oscommerce.sql,v 1.84 2003/05/27 17:32:16 hpdl Exp $
#
# osCommerce, Open Source E-Commerce Solutions
# http://www.oscommerce.com
#
# Copyright (c) 2003 osCommerce
#
# Released under the GNU General Public License
#
# NOTE: * Please make any modifications to this file by hand!
#       * DO NOT use a mysqldump created file for new changes!
#       * Please take note of the table structure, and use this
#         structure as a standard for future modifications!
#       * Any tables you add here should be added in admin/backup.php
#         and in catalog/install/includes/functions/database.php
#       * To see the 'diff'erence between MySQL databases, use
#         the mysqldiff perl script located in the extras
#         directory of the 'catalog' module.
#       * Comments should be like these, full line comments.
#         (don't use inline comments)

DROP TABLE IF EXISTS address_book;
CREATE TABLE address_book (
   address_book_id int NOT NULL auto_increment,
   customers_id int NOT NULL,
   entry_gender char(1) NOT NULL,
   entry_company varchar(32),
   entry_firstname varchar(32) NOT NULL,
   entry_lastname varchar(32) NOT NULL,
   entry_street_address varchar(64) NOT NULL,
   entry_suburb varchar(32),
   entry_postcode varchar(10) NOT NULL,
   entry_city varchar(32) NOT NULL,
   entry_state varchar(32),
   entry_country_id int DEFAULT '0' NOT NULL,
   entry_zone_id int DEFAULT '0' NOT NULL,
   PRIMARY KEY (address_book_id),
   KEY idx_address_book_customers_id (customers_id)
);

DROP TABLE IF EXISTS address_format;
CREATE TABLE address_format (
  address_format_id int NOT NULL auto_increment,
  address_format varchar(128) NOT NULL,
  address_summary varchar(48) NOT NULL,
  PRIMARY KEY (address_format_id)
);

DROP TABLE IF EXISTS banners;
CREATE TABLE banners (
  banners_id int NOT NULL auto_increment,
  banners_title varchar(64) NOT NULL,
  banners_url varchar(255) NOT NULL,
  banners_image varchar(64) NOT NULL,
  banners_group varchar(10) NOT NULL,
  banners_html_text text,
  expires_impressions int(7) DEFAULT '0',
  expires_date datetime DEFAULT NULL,
  date_scheduled datetime DEFAULT NULL,
  date_added datetime NOT NULL,
  date_status_change datetime DEFAULT NULL,
  status int(1) DEFAULT '1' NOT NULL,
  PRIMARY KEY  (banners_id)
);

DROP TABLE IF EXISTS banners_history;
CREATE TABLE banners_history (
  banners_history_id int NOT NULL auto_increment,
  banners_id int NOT NULL,
  banners_shown int(5) NOT NULL DEFAULT '0',
  banners_clicked int(5) NOT NULL DEFAULT '0',
  banners_history_date datetime NOT NULL,
  PRIMARY KEY  (banners_history_id)
);

DROP TABLE IF EXISTS categories;
CREATE TABLE categories (
  categories_id int(11) NOT NULL auto_increment,
  categories_image varchar(64) default NULL,
  parent_id int(11) NOT NULL default '0',
  sort_order int(3) default NULL,
  date_added datetime default NULL,
  last_modified datetime default NULL,
  PRIMARY KEY  (categories_id),
  KEY idx_categories_parent_id (parent_id)
) TYPE=MyISAM;

DROP TABLE IF EXISTS categories_description;
CREATE TABLE categories_description (
  categories_id int(11) NOT NULL default '0',
  language_id int(11) NOT NULL default '1',
  categories_name varchar(32) NOT NULL default '',
  categories_heading_title varchar(64) default NULL,
  categories_description text,
  PRIMARY KEY  (categories_id,language_id),
  KEY idx_categories_name (categories_name)
) TYPE=MyISAM;

DROP TABLE IF EXISTS configuration;
CREATE TABLE configuration (
  configuration_id int NOT NULL auto_increment,
  configuration_title varchar(64) NOT NULL,
  configuration_key varchar(64) NOT NULL,
  configuration_value varchar(255) NOT NULL,
  configuration_description varchar(255) NOT NULL,
  configuration_group_id int NOT NULL,
  sort_order int(5) NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  use_function varchar(255) NULL,
  set_function varchar(255) NULL,
  PRIMARY KEY (configuration_id)
);

DROP TABLE IF EXISTS configuration_group;
CREATE TABLE configuration_group (
  configuration_group_id int NOT NULL auto_increment,
  configuration_group_title varchar(64) NOT NULL,
  configuration_group_description varchar(255) NOT NULL,
  sort_order int(5) NULL,
  visible int(1) DEFAULT '1' NULL,
  PRIMARY KEY (configuration_group_id)
);

DROP TABLE IF EXISTS counter;
CREATE TABLE counter (
  startdate char(8),
  counter int(12)
);

DROP TABLE IF EXISTS counter_history;
CREATE TABLE counter_history (
  month char(8),
  counter int(12)
);

DROP TABLE IF EXISTS countries;
CREATE TABLE countries (
  countries_id int NOT NULL auto_increment,
  countries_name varchar(64) NOT NULL,
  countries_iso_code_2 char(2) NOT NULL,
  countries_iso_code_3 char(3) NOT NULL,
  address_format_id int NOT NULL,
  country_code int(11) unsigned NOT NULL default '0',
  PRIMARY KEY (countries_id),
  KEY IDX_COUNTRIES_NAME (countries_name)
);

DROP TABLE IF EXISTS currencies;
CREATE TABLE currencies (
  currencies_id int NOT NULL auto_increment,
  title varchar(32) NOT NULL,
  code char(3) NOT NULL,
  symbol_left varchar(12),
  symbol_right varchar(12),
  decimal_point char(1),
  thousands_point char(1),
  decimal_places char(1),
  value float(13,8),
  last_updated datetime NULL,
  PRIMARY KEY (currencies_id)
);

DROP TABLE IF EXISTS customers;
CREATE TABLE customers (
   customers_id int NOT NULL auto_increment,
   customers_gender char(1) NOT NULL,
   customers_firstname varchar(32) NOT NULL,
   customers_lastname varchar(32) NOT NULL,
   customers_dob datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
   customers_email_address varchar(96) NOT NULL,
   customers_default_address_id int NOT NULL,
   customers_telephone varchar(32) NOT NULL,
   customers_fax varchar(32),
   customers_password varchar(40) NOT NULL,
   customers_newsletter char(1),
   PRIMARY KEY (customers_id)
);

DROP TABLE IF EXISTS customers_basket;
CREATE TABLE customers_basket (
  customers_basket_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  products_id tinytext NOT NULL,
  customers_basket_quantity int(2) NOT NULL,
  final_price decimal(15,4) NOT NULL,
  customers_basket_date_added char(8),
  PRIMARY KEY (customers_basket_id)
);

DROP TABLE IF EXISTS customers_basket_attributes;
CREATE TABLE customers_basket_attributes (
  customers_basket_attributes_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  products_id tinytext NOT NULL,
  products_options_id int NOT NULL,
  products_options_value_id int NOT NULL,
  PRIMARY KEY (customers_basket_attributes_id)
);

DROP TABLE IF EXISTS customers_info;
CREATE TABLE customers_info (
  customers_info_id int NOT NULL,
  customers_info_date_of_last_logon datetime,
  customers_info_number_of_logons int(5),
  customers_info_date_account_created datetime,
  customers_info_date_account_last_modified datetime,
  global_product_notifications int(1) DEFAULT '0',
  PRIMARY KEY (customers_info_id)
);

DROP TABLE IF EXISTS languages;
CREATE TABLE languages (
  languages_id int NOT NULL auto_increment,
  name varchar(32)  NOT NULL,
  code char(2) NOT NULL,
  image varchar(64),
  directory varchar(32),
  sort_order int(3),
  PRIMARY KEY (languages_id),
  KEY IDX_LANGUAGES_NAME (name)
);


DROP TABLE IF EXISTS manufacturers;
CREATE TABLE manufacturers (
  manufacturers_id int NOT NULL auto_increment,
  manufacturers_name varchar(32) NOT NULL,
  manufacturers_image varchar(64),
  date_added datetime NULL,
  last_modified datetime NULL,
  PRIMARY KEY (manufacturers_id),
  KEY IDX_MANUFACTURERS_NAME (manufacturers_name)
);

DROP TABLE IF EXISTS manufacturers_info;
CREATE TABLE manufacturers_info (
  manufacturers_id int NOT NULL,
  languages_id int NOT NULL,
  manufacturers_url varchar(255) NOT NULL,
  url_clicked int(5) NOT NULL default '0',
  date_last_click datetime NULL,
  PRIMARY KEY (manufacturers_id, languages_id)
);

DROP TABLE IF EXISTS newsletters;
CREATE TABLE newsletters (
  newsletters_id int NOT NULL auto_increment,
  title varchar(255) NOT NULL,
  content text NOT NULL,
  module varchar(255) NOT NULL,
  date_added datetime NOT NULL,
  date_sent datetime,
  status int(1),
  locked int(1) DEFAULT '0',
  PRIMARY KEY (newsletters_id)
);

DROP TABLE IF EXISTS orders;
CREATE TABLE orders (
  orders_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  customers_name varchar(64) NOT NULL,
  customers_company varchar(32),
  customers_street_address varchar(64) NOT NULL,
  customers_suburb varchar(32),
  customers_city varchar(32) NOT NULL,
  customers_postcode varchar(10) NOT NULL,
  customers_state varchar(32),
  customers_country varchar(32) NOT NULL,
  customers_telephone varchar(32) NOT NULL,
  customers_email_address varchar(96) NOT NULL,
  customers_address_format_id int(5) NOT NULL,
  delivery_name varchar(64) NOT NULL,
  delivery_company varchar(32),
  delivery_street_address varchar(64) NOT NULL,
  delivery_suburb varchar(32),
  delivery_city varchar(32) NOT NULL,
  delivery_postcode varchar(10) NOT NULL,
  delivery_state varchar(32),
  delivery_country varchar(32) NOT NULL,
  delivery_address_format_id int(5) NOT NULL,
  billing_name varchar(64) NOT NULL,
  billing_company varchar(32),
  billing_street_address varchar(64) NOT NULL,
  billing_suburb varchar(32),
  billing_city varchar(32) NOT NULL,
  billing_postcode varchar(10) NOT NULL,
  billing_state varchar(32),
  billing_country varchar(32) NOT NULL,
  billing_address_format_id int(5) NOT NULL,
  payment_method varchar(32) NOT NULL,
  cc_type varchar(20),
  cc_owner varchar(64),
  cc_number varchar(32),
  cc_expires varchar(4),
  last_modified datetime,
  date_purchased datetime,
  orders_status int(5) NOT NULL,
  orders_date_finished datetime,
  currency char(3),
  currency_value decimal(14,6),
  PRIMARY KEY (orders_id)
);

DROP TABLE IF EXISTS orders_products;
CREATE TABLE orders_products (
  orders_products_id int NOT NULL auto_increment,
  orders_id int NOT NULL,
  products_id int NOT NULL,
  products_model varchar(12),
  products_name varchar(64) NOT NULL,
  products_price decimal(15,4) NOT NULL,
  final_price decimal(15,4) NOT NULL,
  products_tax decimal(7,4) NOT NULL,
  products_quantity int(2) NOT NULL,
  PRIMARY KEY (orders_products_id)
);

DROP TABLE IF EXISTS orders_status;
CREATE TABLE orders_status (
   orders_status_id int DEFAULT '0' NOT NULL,
   language_id int DEFAULT '1' NOT NULL,
   orders_status_name varchar(32) NOT NULL,
   PRIMARY KEY (orders_status_id, language_id),
   KEY idx_orders_status_name (orders_status_name)
);

DROP TABLE IF EXISTS orders_status_history;
CREATE TABLE orders_status_history (
   orders_status_history_id int NOT NULL auto_increment,
   orders_id int NOT NULL,
   orders_status_id int(5) NOT NULL,
   date_added datetime NOT NULL,
   customer_notified int(1) DEFAULT '0',
   comments text,
   PRIMARY KEY (orders_status_history_id)
);

DROP TABLE IF EXISTS orders_products_attributes;
CREATE TABLE orders_products_attributes (
  orders_products_attributes_id int NOT NULL auto_increment,
  orders_id int NOT NULL,
  orders_products_id int NOT NULL,
  products_options varchar(32) NOT NULL,
  products_options_values varchar(32) NOT NULL,
  options_values_price decimal(15,4) NOT NULL,
  price_prefix char(1) NOT NULL,
  PRIMARY KEY (orders_products_attributes_id)
);

DROP TABLE IF EXISTS orders_products_download;
CREATE TABLE orders_products_download (
  orders_products_download_id int NOT NULL auto_increment,
  orders_id int NOT NULL default '0',
  orders_products_id int NOT NULL default '0',
  orders_products_filename varchar(255) NOT NULL default '',
  download_maxdays int(2) NOT NULL default '0',
  download_count int(2) NOT NULL default '0',
  PRIMARY KEY  (orders_products_download_id)
);

DROP TABLE IF EXISTS orders_total;
CREATE TABLE orders_total (
  orders_total_id int unsigned NOT NULL auto_increment,
  orders_id int NOT NULL,
  title varchar(255) NOT NULL,
  text varchar(255) NOT NULL,
  value decimal(15,4) NOT NULL,
  class varchar(32) NOT NULL,
  sort_order int NOT NULL,
  PRIMARY KEY (orders_total_id),
  KEY idx_orders_total_orders_id (orders_id)
);

DROP TABLE IF EXISTS products;
CREATE TABLE products (
  products_id int NOT NULL auto_increment,
  products_quantity int(4) NOT NULL,
  products_model varchar(12),
  products_image varchar(64),
  products_price decimal(15,4) NOT NULL,
  products_date_added datetime NOT NULL,
  products_last_modified datetime,
  products_date_available datetime,
  products_weight decimal(5,2) NOT NULL,
  products_status tinyint(1) NOT NULL,
  products_tax_class_id int NOT NULL,
  manufacturers_id int NULL,
  products_ordered int NOT NULL default '0',
  PRIMARY KEY (products_id),
  KEY idx_products_date_added (products_date_added)
);

DROP TABLE IF EXISTS products_attributes;
CREATE TABLE products_attributes (
  products_attributes_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  options_id int(11) NOT NULL default '0',
  options_values_id int(11) NOT NULL default '0',
  options_values_price decimal(15,4) NOT NULL default '0.0000',
  price_prefix char(1) NOT NULL default '',
  products_options_sort_order int(6) NOT NULL default '0',
  product_attributes_one_time tinyint(1) NOT NULL default '0',
  products_attributes_weight decimal(5,2) NOT NULL default '0.00',
  products_attributes_weight_prefix char(1) NOT NULL default '',
  products_attributes_units int(4) NOT NULL default '0',
  products_attributes_units_price decimal(15,4) NOT NULL default '0.0000',
  PRIMARY KEY  (products_attributes_id)
) TYPE=MyISAM;

DROP TABLE IF EXISTS products_attributes_download;
CREATE TABLE products_attributes_download (
  products_attributes_id int NOT NULL,
  products_attributes_filename varchar(255) NOT NULL default '',
  products_attributes_maxdays int(2) default '0',
  products_attributes_maxcount int(2) default '0',
  PRIMARY KEY  (products_attributes_id)
);

DROP TABLE IF EXISTS products_description;
CREATE TABLE products_description (
  products_id int NOT NULL auto_increment,
  language_id int NOT NULL default '1',
  products_name varchar(64) NOT NULL default '',
  products_description text,
  products_url varchar(255) default NULL,
  products_viewed int(5) default '0',
  PRIMARY KEY  (products_id,language_id),
  KEY products_name (products_name)
);

DROP TABLE IF EXISTS products_notifications;
CREATE TABLE products_notifications (
  products_id int NOT NULL,
  customers_id int NOT NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (products_id, customers_id)
);

DROP TABLE IF EXISTS products_options;
CREATE TABLE products_options (
  products_options_id int(11) NOT NULL default '0',
  language_id int(11) NOT NULL default '1',
  products_options_name varchar(32) NOT NULL default '',
  products_options_sort_order int(4) NOT NULL default '0',
  PRIMARY KEY  (products_options_id,language_id)
) TYPE=MyISAM;


DROP TABLE IF EXISTS products_options_values;
CREATE TABLE products_options_values (
  products_options_values_id int NOT NULL default '0',
  language_id int NOT NULL default '1',
  products_options_values_name varchar(64) NOT NULL default '',
  PRIMARY KEY  (products_options_values_id,language_id)
);

DROP TABLE IF EXISTS products_options_values_to_products_options;
CREATE TABLE products_options_values_to_products_options (
  products_options_values_to_products_options_id int NOT NULL auto_increment,
  products_options_id int NOT NULL,
  products_options_values_id int NOT NULL,
  PRIMARY KEY (products_options_values_to_products_options_id)
);

DROP TABLE IF EXISTS products_to_categories;
CREATE TABLE products_to_categories (
  products_id int NOT NULL,
  categories_id int NOT NULL,
  PRIMARY KEY (products_id,categories_id)
);

DROP TABLE IF EXISTS reviews;
CREATE TABLE reviews (
  reviews_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  customers_id int,
  customers_name varchar(64) NOT NULL,
  reviews_rating int(1),
  date_added datetime,
  last_modified datetime,
  reviews_read int(5) NOT NULL default '0',
  PRIMARY KEY (reviews_id)
);

DROP TABLE IF EXISTS reviews_description;
CREATE TABLE reviews_description (
  reviews_id int NOT NULL,
  languages_id int NOT NULL,
  reviews_text text NOT NULL,
  PRIMARY KEY (reviews_id, languages_id)
);

DROP TABLE IF EXISTS sessions;
CREATE TABLE sessions (
  sesskey varchar(32) NOT NULL,
  expiry int(11) unsigned NOT NULL,
  value text NOT NULL,
  PRIMARY KEY (sesskey)
);

DROP TABLE IF EXISTS specials;
CREATE TABLE specials (
  specials_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  specials_new_products_price decimal(15,4) NOT NULL,
  specials_date_added datetime,
  specials_last_modified datetime,
  expires_date datetime,
  date_status_change datetime,
  status int(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (specials_id)
);

DROP TABLE IF EXISTS tax_class;
CREATE TABLE tax_class (
  tax_class_id int NOT NULL auto_increment,
  tax_class_title varchar(32) NOT NULL,
  tax_class_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (tax_class_id)
);

DROP TABLE IF EXISTS tax_rates;
CREATE TABLE tax_rates (
  tax_rates_id int NOT NULL auto_increment,
  tax_zone_id int NOT NULL,
  tax_class_id int NOT NULL,
  tax_priority int(5) DEFAULT 1,
  tax_rate decimal(7,4) NOT NULL,
  tax_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (tax_rates_id)
);

DROP TABLE IF EXISTS geo_zones;
CREATE TABLE geo_zones (
  geo_zone_id int NOT NULL auto_increment,
  geo_zone_name varchar(32) NOT NULL,
  geo_zone_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (geo_zone_id)
);

DROP TABLE IF EXISTS whos_online;
CREATE TABLE whos_online (
  customer_id int,
  full_name varchar(64) NOT NULL,
  session_id varchar(128) NOT NULL,
  ip_address varchar(15) NOT NULL,
  time_entry varchar(14) NOT NULL,
  time_last_click varchar(14) NOT NULL,
  last_page_url varchar(64) NOT NULL
);

DROP TABLE IF EXISTS zones;
CREATE TABLE zones (
  zone_id int NOT NULL auto_increment,
  zone_country_id int NOT NULL,
  zone_code varchar(32) NOT NULL,
  zone_name varchar(32) NOT NULL,
  PRIMARY KEY (zone_id)
);

DROP TABLE IF EXISTS zones_to_geo_zones;
CREATE TABLE zones_to_geo_zones (
   association_id int NOT NULL auto_increment,
   zone_country_id int NOT NULL,
   zone_id int NULL,
   geo_zone_id int NULL,
   last_modified datetime NULL,
   date_added datetime NOT NULL,
   PRIMARY KEY (association_id)
);


# data

INSERT INTO address_book VALUES ( '1', '1', 'm', 'ACME Inc.', 'John', 'Doe', '1 Way Street', '', '4895', 'Brisbane', '', '13', '193');

# 1 - Default, 2 - USA, 3 - Spain, 4 - Singapore, 5 - Germany
INSERT INTO address_format VALUES (1, '$firstname $lastname$cr$streets$cr$city, $postcode$cr$statecomma$country','$city / $country');
INSERT INTO address_format VALUES (2, '$firstname $lastname$cr$streets$cr$city, $state    $postcode$cr$country','$city, $state / $country');
INSERT INTO address_format VALUES (3, '$firstname $lastname$cr$streets$cr$city$cr$postcode - $statecomma$country','$state / $country');
INSERT INTO address_format VALUES (4, '$firstname $lastname$cr$streets$cr$city ($postcode)$cr$country', '$postcode / $country');
INSERT INTO address_format VALUES (5, '$firstname $lastname$cr$streets$cr$postcode $city$cr$country','$city / $country');

INSERT INTO banners VALUES (1, 'osCommerce', 'http://www.oscommerce.com', 'banners/oscommerce.gif', '468x50', '', 0, null, null, now(), null, 1);

INSERT INTO categories VALUES (1,'alb_tenology.jpg',0,1,'2005-09-16 22:48:54','2005-09-17 00:19:01');
INSERT INTO categories VALUES (2,'colours_video.jpg',0,2,'2005-09-16 23:10:15','2005-09-17 00:19:50');
INSERT INTO categories VALUES (3,'t_shirt.jpg',0,3,'2005-09-16 23:20:46','2005-09-16 23:36:49');
INSERT INTO categories VALUES (4,'stubby_holder.jpg',0,4,'2005-09-17 00:09:34',NULL);

INSERT INTO categories_description VALUES (1,1,'CD','CD','All CD items');
INSERT INTO categories_description VALUES (2,1,'DVD and Video','DVD and Video','All DVD and videos');
INSERT INTO categories_description VALUES (3,1,'Clothes','Clothes','All Clothes');
INSERT INTO categories_description VALUES (4,1,'Merchandise','Merchandise','All Merchandise');

INSERT INTO configuration VALUES (1,'Store Name','STORE_NAME','osCommRes','The name of my store',1,1,'2005-08-10 05:47:06','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (2,'Store Owner','STORE_OWNER','osCommRes Store Manager','The name of my store owner',1,2,'2005-08-10 05:47:38','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (3,'E-Mail Address','STORE_OWNER_EMAIL_ADDRESS','shop@oscommres.com','The e-mail address of my store owner',1,3,'2005-08-10 05:47:54','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (4,'E-Mail From','EMAIL_FROM','shop@oscommres.com','The e-mail address used in (sent) e-mails',1,4,'2005-08-10 05:48:11','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (5,'Country','STORE_COUNTRY','13','The country my store is located in <br><br><b>Note: Please remember to update the store zone.</b>',1,6,'2003-12-04 09:40:19','2003-07-17 10:29:22','tep_get_country_name','tep_cfg_pull_down_country_list(');
INSERT INTO configuration VALUES (6,'Zone','STORE_ZONE','193','The zone my store is located in',1,7,'2004-02-20 23:10:24','2003-07-17 10:29:22','tep_cfg_get_zone_name','tep_cfg_pull_down_zone_list(');
INSERT INTO configuration VALUES (7,'Expected Sort Order','EXPECTED_PRODUCTS_SORT','desc','This is the sort order used in the expected products box.',1,8,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'asc\', \'desc\'),');
INSERT INTO configuration VALUES (8,'Expected Sort Field','EXPECTED_PRODUCTS_FIELD','date_expected','The column to sort by in the expected products box.',1,9,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'products_name\', \'date_expected\'),');
INSERT INTO configuration VALUES (9,'Switch To Default Language Currency','USE_DEFAULT_LANGUAGE_CURRENCY','true','Automatically switch to the language\'s currency when it is changed',1,10,'2005-09-21 07:39:08','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (10,'Send Extra Order Emails To','SEND_EXTRA_ORDER_EMAILS_TO','','Send extra order emails to the following email addresses, in this format: Name 1 &lt;email@address1&gt;, Name 2 &lt;email@address2&gt;',1,11,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (11,'Use Search-Engine Safe URLs (still in development)','SEARCH_ENGINE_FRIENDLY_URLS','true','Use search-engine safe urls for all site links',1,12,'2004-12-07 17:22:09','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (12,'Display Cart After Adding Product','DISPLAY_CART','true','Display the shopping cart after adding a product (or return back to their origin)',1,14,'2004-02-21 00:57:00','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (13,'Allow Guest To Tell A Friend','ALLOW_GUEST_TO_TELL_A_FRIEND','false','Allow guests to tell a friend about a product',1,15,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (14,'Default Search Operator','ADVANCED_SEARCH_DEFAULT_OPERATOR','and','Default search operators',1,17,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'and\', \'or\'),');
INSERT INTO configuration VALUES (15,'Store Address and Phone','STORE_NAME_ADDRESS','osCommRes Pty Ltd\r\nABN 123456789\r\nGPO Box 1234\r\nBrisbane QLD 4001\r\nAustralia\r\ntel 123456789','This is the Store Name, Address and Phone used on printable documents and displayed online',1,18,'2005-08-10 05:49:22','2003-07-17 10:29:22',NULL,'tep_cfg_textarea(');
INSERT INTO configuration VALUES (16,'Show Category Counts','SHOW_COUNTS','true','Count recursively how many products are in each category',1,19,'2005-09-21 07:30:50','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (17,'Tax Decimal Places','TAX_DECIMAL_PLACES','0','Pad the tax value this amount of decimal places',1,20,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (18,'Display Prices with Tax','DISPLAY_PRICE_WITH_TAX','true','Display prices with tax included (true) or add the tax at the end (false)',1,21,'2005-01-25 00:18:41','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (19,'First Name','ENTRY_FIRST_NAME_MIN_LENGTH','2','Minimum length of first name',2,1,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (20,'Last Name','ENTRY_LAST_NAME_MIN_LENGTH','2','Minimum length of last name',2,2,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (21,'Date of Birth','ENTRY_DOB_MIN_LENGTH','10','Minimum length of date of birth',2,3,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (22,'E-Mail Address','ENTRY_EMAIL_ADDRESS_MIN_LENGTH','6','Minimum length of e-mail address',2,4,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (23,'Street Address','ENTRY_STREET_ADDRESS_MIN_LENGTH','5','Minimum length of street address',2,5,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (24,'Company','ENTRY_COMPANY_MIN_LENGTH','2','Minimum length of company name',2,6,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (25,'Post Code','ENTRY_POSTCODE_MIN_LENGTH','4','Minimum length of post code',2,7,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (26,'City','ENTRY_CITY_MIN_LENGTH','3','Minimum length of city',2,8,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (27,'State','ENTRY_STATE_MIN_LENGTH','2','Minimum length of state',2,9,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (28,'Telephone Number','ENTRY_TELEPHONE_MIN_LENGTH','8','Minimum length of telephone number',2,10,'2003-12-04 11:15:33','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (29,'Password','ENTRY_PASSWORD_MIN_LENGTH','6','Minimum length of password',2,11,'2003-12-04 11:15:41','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (30,'Credit Card Owner Name','CC_OWNER_MIN_LENGTH','6','Minimum length of credit card owner name',2,12,'2004-02-20 23:14:01','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (31,'Credit Card Number','CC_NUMBER_MIN_LENGTH','12','Minimum length of credit card number',2,13,'2004-02-20 23:13:45','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (32,'Review Text','REVIEW_TEXT_MIN_LENGTH','50','Minimum length of review text',2,14,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (33,'Best Sellers','MIN_DISPLAY_BESTSELLERS','1','Minimum number of best sellers to display',2,15,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (34,'Also Purchased','MIN_DISPLAY_ALSO_PURCHASED','1','Minimum number of products to display in the \'This Customer Also Purchased\' box',2,16,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (35,'Address Book Entries','MAX_ADDRESS_BOOK_ENTRIES','5','Maximum address book entries a customer is allowed to have',3,1,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (36,'Search Results','MAX_DISPLAY_SEARCH_RESULTS','10','Amount of products to list',3,2,'2003-08-06 12:35:41','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (37,'Page Links','MAX_DISPLAY_PAGE_LINKS','5','Number of \'number\' links use for page-sets',3,3,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (38,'Special Products','MAX_DISPLAY_SPECIAL_PRODUCTS','3','Maximum number of products on special to display',3,4,'2003-08-06 12:35:27','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (39,'New Products Module','MAX_DISPLAY_NEW_PRODUCTS','3','Maximum number of new products to display in a category',3,5,'2003-08-06 12:35:10','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (40,'Products Expected','MAX_DISPLAY_UPCOMING_PRODUCTS','3','Maximum number of products expected to display',3,6,'2003-08-06 12:36:07','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (41,'Manufacturers List','MAX_DISPLAY_MANUFACTURERS_IN_A_LIST','5','Used in manufacturers box; when the number of manufacturers exceeds this number, a drop-down list will be displayed instead of the default list',3,7,'2003-10-04 02:47:35','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (42,'Manufacturers Select Size','MAX_MANUFACTURERS_LIST','1','Used in manufacturers box; when this value is \'1\' the classic drop-down list will be used for the manufacturers box. Otherwise, a list-box with the specified number of rows will be displayed.',3,7,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (43,'Length of Manufacturers Name','MAX_DISPLAY_MANUFACTURER_NAME_LEN','15','Used in manufacturers box; maximum length of manufacturers name to display',3,8,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (44,'New Reviews','MAX_DISPLAY_NEW_REVIEWS','6','Maximum number of new reviews to display',3,9,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (45,'Selection of Random Reviews','MAX_RANDOM_SELECT_REVIEWS','10','How many records to select from to choose one random product review',3,10,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (46,'Selection of Random New Products','MAX_RANDOM_SELECT_NEW','10','How many records to select from to choose one random new product to display',3,11,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (47,'Selection of Products on Special','MAX_RANDOM_SELECT_SPECIALS','10','How many records to select from to choose one random product special to display',3,12,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (48,'Categories To List Per Row','MAX_DISPLAY_CATEGORIES_PER_ROW','3','How many categories to list per row',3,13,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (49,'New Products Listing','MAX_DISPLAY_PRODUCTS_NEW','8','Maximum number of new products to display in new products page',3,14,'2003-08-29 22:56:22','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (50,'Best Sellers','MAX_DISPLAY_BESTSELLERS','10','Maximum number of best sellers to display',3,15,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (51,'Also Purchased','MAX_DISPLAY_ALSO_PURCHASED','6','Maximum number of products to display in the \'This Customer Also Purchased\' box',3,16,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (52,'Customer Order History Box','MAX_DISPLAY_PRODUCTS_IN_ORDER_HISTORY_BOX','6','Maximum number of products to display in the customer order history box',3,17,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (53,'Order History','MAX_DISPLAY_ORDER_HISTORY','10','Maximum number of orders to display in the order history page',3,18,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (54,'Small Image Width','SMALL_IMAGE_WIDTH','100','The pixel width of small images',4,1,'2003-09-01 20:30:19','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (55,'Small Image Height','SMALL_IMAGE_HEIGHT','80','The pixel height of small images',4,2,'2004-02-20 18:21:01','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (56,'Heading Image Width','HEADING_IMAGE_WIDTH','57','The pixel width of heading images',4,3,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (57,'Heading Image Height','HEADING_IMAGE_HEIGHT','40','The pixel height of heading images',4,4,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (58,'Subcategory Image Width','SUBCATEGORY_IMAGE_WIDTH','100','The pixel width of subcategory images',4,5,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (59,'Subcategory Image Height','SUBCATEGORY_IMAGE_HEIGHT','80','The pixel height of subcategory images',4,6,'2004-02-20 18:20:26','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (60,'Calculate Image Size','CONFIG_CALCULATE_IMAGE_SIZE','true','Calculate the size of images?',4,7,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (61,'Image Required','IMAGE_REQUIRED','true','Enable to display broken images. Good for development.',4,8,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (62,'Gender','ACCOUNT_GENDER','true','Display gender in the customers account',5,1,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (63,'Date of Birth','ACCOUNT_DOB','true','Display date of birth in the customers account',5,2,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (64,'Company','ACCOUNT_COMPANY','false','Display company in the customers account',5,3,'2004-02-09 11:17:21','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (65,'Suburb','ACCOUNT_SUBURB','true','Display suburb in the customers account',5,4,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (66,'State','ACCOUNT_STATE','true','Display state in the customers account',5,5,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (67,'Installed Modules','MODULE_PAYMENT_INSTALLED','cash.php;moneyorder.php;virtualpay.php','List of payment module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: cc.php;cod.php;paypal.php)',6,0,'2005-08-31 22:31:00','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (68,'Installed Modules','MODULE_ORDER_TOTAL_INSTALLED','ot_subtotal.php;ot_shipping.php;ot_tax.php;ot_gv.php;ot_coupon.php;ot_total.php','List of order_total module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)',6,0,'2004-02-21 03:45:39','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (69,'Installed Modules','MODULE_SHIPPING_INSTALLED','auspost.php;auspostair.php;ausposteconomy.php;auspostexpress.php;auspostsea.php','List of shipping module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ups.php;flat.php;item.php)',6,0,'2004-09-19 15:55:06','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (84,'Default Currency','DEFAULT_CURRENCY','AUD','Default Currency',6,0,'2003-09-06 22:01:21','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (85,'Default Language','DEFAULT_LANGUAGE','en','Default Language',6,0,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (86,'Default Order Status For New Orders','DEFAULT_ORDERS_STATUS_ID','1','When a new order is created, this order status will be assigned to it.',6,0,'2004-02-20 19:40:01','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (1297,'Tax Class','MODULE_SHIPPING_AUSPOST_EXPRESS_TAX_CLASS','2','Use the following tax class on the shipping fee.',6,0,NULL,'2004-02-21 02:45:42','tep_get_tax_class_title','tep_cfg_pull_down_tax_classes(');
INSERT INTO configuration VALUES (1295,'Parcel Depth','MODULE_SHIPPING_AUSPOST_EXPRESS_SDEPTH','100','Parcel Depth (in mm)',6,0,NULL,'2004-02-21 02:45:42',NULL,NULL);
INSERT INTO configuration VALUES (1296,'Shipping Zone','MODULE_SHIPPING_AUSPOST_EXPRESS_ZONE','3','If a zone is selected, only enable this shipping method for that zone.',6,0,NULL,'2004-02-21 02:45:42','tep_get_zone_class_title','tep_cfg_pull_down_zone_classes(');
INSERT INTO configuration VALUES (1294,'Parcel Width','MODULE_SHIPPING_AUSPOST_EXPRESS_SWIDTH','100','Parcel Width (in mm)',6,0,NULL,'2004-02-21 02:45:42',NULL,NULL);
INSERT INTO configuration VALUES (1292,'Handling Fee','MODULE_SHIPPING_AUSPOST_EXPRESS_HANDLING','2','Handling Fee for this shipping method',6,0,NULL,'2004-02-21 02:45:42',NULL,NULL);
INSERT INTO configuration VALUES (1293,'Parcel Height','MODULE_SHIPPING_AUSPOST_EXPRESS_SHEIGHT','100','Parcel Height (in mm)',6,0,NULL,'2004-02-21 02:45:42',NULL,NULL);
INSERT INTO configuration VALUES (1291,'Dispatch Postcode','MODULE_SHIPPING_AUSPOST_EXPRESS_SPCODE','4066','Dispatch Postcode?',6,0,NULL,'2004-02-21 02:45:42',NULL,NULL);
INSERT INTO configuration VALUES (1312,'Sort Order','MODULE_ORDER_TOTAL_TAX_SORT_ORDER','3','Sort order of display.',6,2,NULL,'2004-02-21 03:36:45',NULL,NULL);
INSERT INTO configuration VALUES (1290,'Insurance','MODULE_SHIPPING_AUSPOST_EXPRESS_INSURANCE','','Insurance cost is based on the total cost of items. Example: 25:8.50,50:5.50,etc.. Up to $25 charge $8.50, from there to $50 charge $5.50, etc',6,0,NULL,'2004-02-21 02:45:42',NULL,NULL);
INSERT INTO configuration VALUES (96,'Display Total','MODULE_ORDER_TOTAL_TOTAL_STATUS','true','Do you want to display the total order value?',6,4,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (1283,'Parcel Height','MODULE_SHIPPING_AUSPOST_ECONOMY_SHEIGHT','100','Parcel Height (in mm)',6,0,NULL,'2004-02-21 02:45:06',NULL,NULL);
INSERT INTO configuration VALUES (98,'Country of Origin','SHIPPING_ORIGIN_COUNTRY','13','Select the country of origin to be used in shipping quotes.',7,1,'2003-12-04 12:11:29','2003-07-17 10:29:22','tep_get_country_name','tep_cfg_pull_down_country_list(');
INSERT INTO configuration VALUES (99,'Postal Code','SHIPPING_ORIGIN_ZIP','4066','Enter the Postal Code (ZIP) of the Store to be used in shipping quotes.',7,2,'2003-12-04 12:11:37','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (100,'Enter the Maximum Package Weight you will ship','SHIPPING_MAX_WEIGHT','50','Carriers have a max weight limit for a single package. This is a common one for all.',7,3,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (101,'Package Tare weight.','SHIPPING_BOX_WEIGHT','0','What is the weight of typical packaging of small to medium packages?',7,4,'2003-07-29 15:06:50','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (102,'Larger packages - percentage increase.','SHIPPING_BOX_PADDING','10','For 10% enter 10',7,5,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (103,'Display Product Image','PRODUCT_LIST_IMAGE','1','Do you want to display the Product Image?',8,1,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (104,'Display Product Manufaturer Name','PRODUCT_LIST_MANUFACTURER','0','Do you want to display the Product Manufacturer Name?',8,2,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (105,'Display Product Model','PRODUCT_LIST_MODEL','0','Do you want to display the Product Model?',8,3,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (106,'Display Product Name','PRODUCT_LIST_NAME','2','Do you want to display the Product Name?',8,4,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (107,'Display Product Price','PRODUCT_LIST_PRICE','3','Do you want to display the Product Price',8,5,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (108,'Display Product Quantity','PRODUCT_LIST_QUANTITY','0','Do you want to display the Product Quantity?',8,6,'2005-01-24 16:31:08','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (109,'Display Product Weight','PRODUCT_LIST_WEIGHT','0','Do you want to display the Product Weight?',8,7,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (110,'Display Buy Now column','PRODUCT_LIST_BUY_NOW','4','Do you want to display the Buy Now column?',8,8,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (111,'Display Category/Manufacturer Filter (0=disable; 1=enable)','PRODUCT_LIST_FILTER','1','Do you want to display the Category/Manufacturer Filter?',8,9,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (112,'Location of Prev/Next Navigation Bar (1-top, 2-bottom, 3-both)','PREV_NEXT_BAR_LOCATION','3','Sets the location of the Prev/Next Navigation Bar (1-top, 2-bottom, 3-both)',8,10,'2003-10-05 19:19:32','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (113,'Check stock level','STOCK_CHECK','true','Check to see if sufficent stock is available',9,1,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (114,'Subtract stock','STOCK_LIMITED','true','Subtract product in stock by product orders',9,2,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (115,'Allow Checkout','STOCK_ALLOW_CHECKOUT','true','Allow customer to checkout even if there is insufficient stock',9,3,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (116,'Mark product out of stock','STOCK_MARK_PRODUCT_OUT_OF_STOCK','***','Display something on screen so customer can see which product has insufficient stock',9,4,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (117,'Stock Re-order level','STOCK_REORDER_LEVEL','5','Define when stock needs to be re-ordered',9,5,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (118,'Store Page Parse Time','STORE_PAGE_PARSE_TIME','false','Store the time it takes to parse a page',10,1,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (119,'Log Destination','STORE_PAGE_PARSE_TIME_LOG','/var/log/www/tep/page_parse_time.log','Directory and filename of the page parse time log',10,2,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (120,'Log Date Format','STORE_PARSE_DATE_TIME_FORMAT','%d/%m/%Y %H:%M:%S','The date format',10,3,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (121,'Display The Page Parse Time','DISPLAY_PAGE_PARSE_TIME','true','Display the page parse time (store page parse time must be enabled)',10,4,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (122,'Store Database Queries','STORE_DB_TRANSACTIONS','false','Store the database queries in the page parse time log (PHP4 only)',10,5,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (123,'Use Cache','USE_CACHE','true','Use caching features',11,1,'2003-08-28 21:53:54','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (124,'Cache Directory','DIR_FS_CACHE','/tmp/','The directory where the cached files are saved',11,2,'2003-07-17 10:42:27','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (125,'E-Mail Transport Method','EMAIL_TRANSPORT','sendmail','Defines if this server uses a local connection to sendmail or uses an SMTP connection via TCP/IP. Servers running on Windows and MacOS should change this setting to SMTP.',12,1,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'sendmail\', \'smtp\'),');
INSERT INTO configuration VALUES (126,'E-Mail Linefeeds','EMAIL_LINEFEED','LF','Defines the character sequence used to separate mail headers.',12,2,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'LF\', \'CRLF\'),');
INSERT INTO configuration VALUES (127,'Use MIME HTML When Sending Emails','EMAIL_USE_HTML','false','Send e-mails in HTML format',12,3,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (128,'Verify E-Mail Addrsses Through DNS','ENTRY_EMAIL_ADDRESSES_CHECK','false','Verify e-mail address through a DNS server',12,4,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (129,'Send E-Mails','SEND_EMAILS','true','Send out e-mails',12,5,'2004-02-10 18:36:22','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (130,'Enable download','DOWNLOAD_ENABLED','true','Enable the products download functions.',13,1,'2003-07-29 15:38:22','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (131,'Download by redirect','DOWNLOAD_BY_REDIRECT','true','Use browser redirection for download. Disable on non-Unix systems.',13,2,'2003-07-29 15:06:20','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (132,'Expiry delay (days)','DOWNLOAD_MAX_DAYS','7','Set number of days before the download link expires. 0 means no limit.',13,3,NULL,'2003-07-17 10:29:22',NULL,'');
INSERT INTO configuration VALUES (133,'Maximum number of downloads','DOWNLOAD_MAX_COUNT','5','Set the maximum number of downloads. 0 means no download authorized.',13,4,NULL,'2003-07-17 10:29:22',NULL,'');
INSERT INTO configuration VALUES (134,'Enable GZip Compression','GZIP_COMPRESSION','false','Enable HTTP GZip compression.',14,1,'2003-08-12 00:20:39','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),');
INSERT INTO configuration VALUES (135,'Compression Level','GZIP_LEVEL','5','Use this compression level 0-9 (0 = minimum, 9 = maximum).',14,2,NULL,'2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (136,'Session Directory','SESSION_WRITE_DIRECTORY','/tmp','If sessions are file based, store them in this directory.',15,1,'2003-08-05 12:12:28','2003-07-17 10:29:22',NULL,NULL);
INSERT INTO configuration VALUES (137,'Force Cookie Use','SESSION_FORCE_COOKIE_USE','False','Force the use of sessions when cookies are only enabled.',15,2,'2003-08-29 18:38:35','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),');
INSERT INTO configuration VALUES (138,'Check SSL Session ID','SESSION_CHECK_SSL_SESSION_ID','True','Validate the SSL_SESSION_ID on every secure HTTPS page request.',15,3,'2003-08-28 18:18:22','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),');
INSERT INTO configuration VALUES (139,'Check User Agent','SESSION_CHECK_USER_AGENT','False','Validate the clients browser user agent on every page request.',15,4,NULL,'2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),');
INSERT INTO configuration VALUES (140,'Check IP Address','SESSION_CHECK_IP_ADDRESS','True','Validate the clients IP address on every page request.',15,5,'2003-08-28 18:18:30','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),');
INSERT INTO configuration VALUES (141,'Prevent Spider Sessions','SESSION_BLOCK_SPIDERS','True','Prevent known spiders from starting a session.',15,6,'2003-07-17 10:34:45','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),');
INSERT INTO configuration VALUES (142,'Recreate Session','SESSION_RECREATE','True','Recreate the session to generate a new session ID when the customer logs on or creates an account (PHP >=4.1 needed).',15,7,'2003-07-17 10:35:04','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),');

INSERT INTO configuration_group VALUES (1,'My Store','General information about my store',1,1);
INSERT INTO configuration_group VALUES (2,'Minimum Values','The minimum values for functions / data',2,1);
INSERT INTO configuration_group VALUES (3,'Maximum Values','The maximum values for functions / data',3,1);
INSERT INTO configuration_group VALUES (4,'Images','Image parameters',4,1);
INSERT INTO configuration_group VALUES (5,'Customer Details','Customer account configuration',5,1);
INSERT INTO configuration_group VALUES (6,'Module Options','Hidden from configuration',6,1);
INSERT INTO configuration_group VALUES (7,'Shipping/Packaging','Shipping options available at my store',7,1);
INSERT INTO configuration_group VALUES (8,'Product Listing','Product Listing    configuration options',8,1);
INSERT INTO configuration_group VALUES (9,'Stock','Stock configuration options',9,1);
INSERT INTO configuration_group VALUES (10,'Logging','Logging configuration options',10,1);
INSERT INTO configuration_group VALUES (11,'Cache','Caching configuration options',11,1);
INSERT INTO configuration_group VALUES (12,'E-Mail Options','General setting for E-Mail transport and HTML E-Mails',12,1);
INSERT INTO configuration_group VALUES (13,'Download','Downloadable products options',13,1);
INSERT INTO configuration_group VALUES (14,'GZip Compression','GZip compression options',14,1);
INSERT INTO configuration_group VALUES (15,'Sessions','Session options',15,1);


#updates from 3-12-05

INSERT INTO countries VALUES (1, 'Afghanistan', 'AF', 'AFG', 1, 93);
INSERT INTO countries VALUES (2, 'Albania', 'AL', 'ALB', 1, 355);
INSERT INTO countries VALUES (3, 'Algeria', 'DZ', 'DZA', 1, 213);
INSERT INTO countries VALUES (4, 'American Samoa', 'AS', 'ASM', 1, 684);
INSERT INTO countries VALUES (5, 'Andorra', 'AD', 'AND', 1, 376);
INSERT INTO countries VALUES (6, 'Angola', 'AO', 'AGO', 1, 244);
INSERT INTO countries VALUES (7, 'Anguilla', 'AI', 'AIA', 1, 1264);
INSERT INTO countries VALUES (8, 'Antarctica', 'AQ', 'ATA', 1, 67212);
INSERT INTO countries VALUES (9, 'Antigua and Barbuda', 'AG', 'ATG', 1, 268);
INSERT INTO countries VALUES (10, 'Argentina', 'AR', 'ARG', 1, 54);
INSERT INTO countries VALUES (11, 'Armenia', 'AM', 'ARM', 1, 374);
INSERT INTO countries VALUES (12, 'Aruba', 'AW', 'ABW', 1, 297);
INSERT INTO countries VALUES (13, 'Australia', 'AU', 'AUS', 1, 61);
INSERT INTO countries VALUES (14, 'Austria', 'AT', 'AUT', 5, 43);
INSERT INTO countries VALUES (15, 'Azerbaijan', 'AZ', 'AZE', 1, 994);
INSERT INTO countries VALUES (16, 'Bahamas', 'BS', 'BHS', 1, 1242);
INSERT INTO countries VALUES (17, 'Bahrain', 'BH', 'BHR', 1, 973);
INSERT INTO countries VALUES (18, 'Bangladesh', 'BD', 'BGD', 1, 880);
INSERT INTO countries VALUES (19, 'Barbados', 'BB', 'BRB', 1, 1246);
INSERT INTO countries VALUES (20, 'Belarus', 'BY', 'BLR', 1, 375);
INSERT INTO countries VALUES (21, 'Belgium', 'BE', 'BEL', 1, 32);
INSERT INTO countries VALUES (22, 'Belize', 'BZ', 'BLZ', 1, 501);
INSERT INTO countries VALUES (23, 'Benin', 'BJ', 'BEN', 1, 229);
INSERT INTO countries VALUES (24, 'Bermuda', 'BM', 'BMU', 1, 1441);
INSERT INTO countries VALUES (25, 'Bhutan', 'BT', 'BTN', 1, 975);
INSERT INTO countries VALUES (26, 'Bolivia', 'BO', 'BOL', 1, 591);
INSERT INTO countries VALUES (27, 'Bosnia and Herzegowina', 'BA', 'BIH', 1, 387);
INSERT INTO countries VALUES (28, 'Botswana', 'BW', 'BWA', 1, 267);
INSERT INTO countries VALUES (29, 'Bouvet Island', 'BV', 'BVT', 1, 0);
INSERT INTO countries VALUES (30, 'Brazil', 'BR', 'BRA', 1, 55);
INSERT INTO countries VALUES (31, 'British Indian Ocean Territory', 'IO', 'IOT', 1, 1284);
INSERT INTO countries VALUES (32, 'Brunei Darussalam', 'BN', 'BRN', 1, 673);
INSERT INTO countries VALUES (33, 'Bulgaria', 'BG', 'BGR', 1, 359);
INSERT INTO countries VALUES (34, 'Burkina Faso', 'BF', 'BFA', 1, 226);
INSERT INTO countries VALUES (35, 'Burundi', 'BI', 'BDI', 1, 257);
INSERT INTO countries VALUES (36, 'Cambodia', 'KH', 'KHM', 1, 855);
INSERT INTO countries VALUES (37, 'Cameroon', 'CM', 'CMR', 1, 237);
INSERT INTO countries VALUES (38, 'Canada', 'CA', 'CAN', 1, 1);
INSERT INTO countries VALUES (39, 'Cape Verde', 'CV', 'CPV', 1, 238);
INSERT INTO countries VALUES (40, 'Cayman Islands', 'KY', 'CYM', 1, 1345);
INSERT INTO countries VALUES (41, 'Central African Republic', 'CF', 'CAF', 1, 236);
INSERT INTO countries VALUES (42, 'Chad', 'TD', 'TCD', 1, 235);
INSERT INTO countries VALUES (43, 'Chile', 'CL', 'CHL', 1, 56);
INSERT INTO countries VALUES (44, 'China', 'CN', 'CHN', 1, 86);
INSERT INTO countries VALUES (45, 'Christmas Island', 'CX', 'CXR', 1, 6724);
INSERT INTO countries VALUES (46, 'Cocos (Keeling) Islands', 'CC', 'CCK', 1, 6722);
INSERT INTO countries VALUES (47, 'Colombia', 'CO', 'COL', 1, 57);
INSERT INTO countries VALUES (48, 'Comoros', 'KM', 'COM', 1, 269);
INSERT INTO countries VALUES (49, 'Congo', 'CG', 'COG', 1, 243);
INSERT INTO countries VALUES (240, 'Congo -Democractic Republic', 'CD', 'COD', 1, 242);
INSERT INTO countries VALUES (50, 'Cook Islands', 'CK', 'COK', 1, 682);
INSERT INTO countries VALUES (51, 'Costa Rica', 'CR', 'CRI', 1, 506);
INSERT INTO countries VALUES (52, 'Cote D\'Ivoire', 'CI', 'CIV', 1, 225);
INSERT INTO countries VALUES (53, 'Croatia', 'HR', 'HRV', 1, 385);
INSERT INTO countries VALUES (54, 'Cuba', 'CU', 'CUB', 1, 53);
INSERT INTO countries VALUES (55, 'Cyprus', 'CY', 'CYP', 1, 357);
INSERT INTO countries VALUES (56, 'Czech Republic', 'CZ', 'CZE', 1, 420);
INSERT INTO countries VALUES (57, 'Denmark', 'DK', 'DNK', 1, 45);
INSERT INTO countries VALUES (58, 'Djibouti', 'DJ', 'DJI', 1, 253);
INSERT INTO countries VALUES (59, 'Dominica', 'DM', 'DMA', 1, 1767);
INSERT INTO countries VALUES (60, 'Dominican Republic', 'DO', 'DOM', 1, 1809);
INSERT INTO countries VALUES (61, 'East Timor', 'TP', 'TMP', 1, 670);
INSERT INTO countries VALUES (62, 'Ecuador', 'EC', 'ECU', 1, 593);
INSERT INTO countries VALUES (63, 'Egypt', 'EG', 'EGY', 1, 20);
INSERT INTO countries VALUES (64, 'El Salvador', 'SV', 'SLV', 1, 503);
INSERT INTO countries VALUES (65, 'Equatorial Guinea', 'GQ', 'GNQ', 1, 240);
INSERT INTO countries VALUES (66, 'Eritrea', 'ER', 'ERI', 1, 291);
INSERT INTO countries VALUES (67, 'Estonia', 'EE', 'EST', 1, 372);
INSERT INTO countries VALUES (68, 'Ethiopia', 'ET', 'ETH', 1, 251);
INSERT INTO countries VALUES (69, 'Falkland Islands (Malvinas)', 'FK', 'FLK', 1, 500);
INSERT INTO countries VALUES (70, 'Faroe Islands', 'FO', 'FRO', 1, 298);
INSERT INTO countries VALUES (71, 'Fiji', 'FJ', 'FJI', 1, 679);
INSERT INTO countries VALUES (72, 'Finland', 'FI', 'FIN', 1, 358);
INSERT INTO countries VALUES (73, 'France', 'FR', 'FRA', 1, 33);
INSERT INTO countries VALUES (74, 'France  Metropolitan', 'FX', 'FXX', 1, 0);
INSERT INTO countries VALUES (75, 'French Guiana', 'GF', 'GUF', 1, 594);
INSERT INTO countries VALUES (76, 'French Polynesia', 'PF', 'PYF', 1, 689);
INSERT INTO countries VALUES (77, 'French Southern Territories', 'TF', 'ATF', 1, 596);
INSERT INTO countries VALUES (78, 'Gabon', 'GA', 'GAB', 1, 241);
INSERT INTO countries VALUES (79, 'Gambia', 'GM', 'GMB', 1, 220);
INSERT INTO countries VALUES (80, 'Georgia', 'GE', 'GEO', 1, 995);
INSERT INTO countries VALUES (81, 'Germany', 'DE', 'DEU', 5, 49);
INSERT INTO countries VALUES (82, 'Ghana', 'GH', 'GHA', 1, 233);
INSERT INTO countries VALUES (83, 'Gibraltar', 'GI', 'GIB', 1, 350);
INSERT INTO countries VALUES (84, 'Greece', 'GR', 'GRC', 1, 30);
INSERT INTO countries VALUES (85, 'Greenland', 'GL', 'GRL', 1, 299);
INSERT INTO countries VALUES (86, 'Grenada', 'GD', 'GRD', 1, 1473);
INSERT INTO countries VALUES (87, 'Guadeloupe', 'GP', 'GLP', 1, 590);
INSERT INTO countries VALUES (88, 'Guam', 'GU', 'GUM', 1, 1671);
INSERT INTO countries VALUES (89, 'Guatemala', 'GT', 'GTM', 1, 502);
INSERT INTO countries VALUES (90, 'Guinea', 'GN', 'GIN', 1, 224);
INSERT INTO countries VALUES (91, 'Guinea-bissau', 'GW', 'GNB', 1, 245);
INSERT INTO countries VALUES (92, 'Guyana', 'GY', 'GUY', 1, 592);
INSERT INTO countries VALUES (93, 'Haiti', 'HT', 'HTI', 1, 509);
INSERT INTO countries VALUES (94, 'Heard and Mc Donald Islands', 'HM', 'HMD', 1, 0);
INSERT INTO countries VALUES (95, 'Honduras', 'HN', 'HND', 1, 504);
INSERT INTO countries VALUES (96, 'Hong Kong', 'HK', 'HKG', 1, 852);
INSERT INTO countries VALUES (97, 'Hungary', 'HU', 'HUN', 1, 36);
INSERT INTO countries VALUES (98, 'Iceland', 'IS', 'ISL', 1, 354);
INSERT INTO countries VALUES (99, 'India', 'IN', 'IND', 1, 91);
INSERT INTO countries VALUES (100, 'Indonesia', 'ID', 'IDN', 1, 62);
INSERT INTO countries VALUES (101, 'Iran (Islamic Republic of)', 'IR', 'IRN', 1, 98);
INSERT INTO countries VALUES (102, 'Iraq', 'IQ', 'IRQ', 1, 964);
INSERT INTO countries VALUES (103, 'Ireland', 'IE', 'IRL', 1, 353);
INSERT INTO countries VALUES (104, 'Israel', 'IL', 'ISR', 1, 972);
INSERT INTO countries VALUES (105, 'Italy', 'IT', 'ITA', 1, 39);
INSERT INTO countries VALUES (106, 'Jamaica', 'JM', 'JAM', 1, 1876);
INSERT INTO countries VALUES (107, 'Japan', 'JP', 'JPN', 1, 81);
INSERT INTO countries VALUES (108, 'Jordan', 'JO', 'JOR', 1, 962);
INSERT INTO countries VALUES (109, 'Kazakhstan', 'KZ', 'KAZ', 1, 7);
INSERT INTO countries VALUES (110, 'Kenya', 'KE', 'KEN', 1, 254);
INSERT INTO countries VALUES (111, 'Kiribati', 'KI', 'KIR', 1, 686);
INSERT INTO countries VALUES (112, 'Korea Democratic People\'s Republic of', 'KP', 'PRK', 1, 850);
INSERT INTO countries VALUES (113, 'Korea Republic of', 'KR', 'KOR', 1, 82);
INSERT INTO countries VALUES (114, 'Kuwait', 'KW', 'KWT', 1, 965);
INSERT INTO countries VALUES (115, 'Kyrgyzstan', 'KG', 'KGZ', 1, 7);
INSERT INTO countries VALUES (116, 'Lao People\'s Democratic Republic', 'LA', 'LAO', 1, 856);
INSERT INTO countries VALUES (117, 'Latvia', 'LV', 'LVA', 1, 371);
INSERT INTO countries VALUES (118, 'Lebanon', 'LB', 'LBN', 1, 961);
INSERT INTO countries VALUES (119, 'Lesotho', 'LS', 'LSO', 1, 266);
INSERT INTO countries VALUES (120, 'Liberia', 'LR', 'LBR', 1, 231);
INSERT INTO countries VALUES (121, 'Libyan Arab Jamahiriya', 'LY', 'LBY', 1, 218);
INSERT INTO countries VALUES (122, 'Liechtenstein', 'LI', 'LIE', 1, 423);
INSERT INTO countries VALUES (123, 'Lithuania', 'LT', 'LTU', 1, 370);
INSERT INTO countries VALUES (124, 'Luxembourg', 'LU', 'LUX', 1, 352);
INSERT INTO countries VALUES (125, 'Macau', 'MO', 'MAC', 1, 853);
INSERT INTO countries VALUES (126, 'Macedonia  The Former Yugoslav Republic of', 'MK', 'MKD', 1, 389);
INSERT INTO countries VALUES (127, 'Madagascar', 'MG', 'MDG', 1, 261);
INSERT INTO countries VALUES (128, 'Malawi', 'MW', 'MWI', 1, 265);
INSERT INTO countries VALUES (129, 'Malaysia', 'MY', 'MYS', 1, 60);
INSERT INTO countries VALUES (130, 'Maldives', 'MV', 'MDV', 1, 960);
INSERT INTO countries VALUES (131, 'Mali', 'ML', 'MLI', 1, 223);
INSERT INTO countries VALUES (132, 'Malta', 'MT', 'MLT', 1, 356);
INSERT INTO countries VALUES (133, 'Marshall Islands', 'MH', 'MHL', 1, 692);
INSERT INTO countries VALUES (134, 'Martinique', 'MQ', 'MTQ', 1, 596);
INSERT INTO countries VALUES (135, 'Mauritania', 'MR', 'MRT', 1, 222);
INSERT INTO countries VALUES (136, 'Mauritius', 'MU', 'MUS', 1, 230);
INSERT INTO countries VALUES (137, 'Mayotte', 'YT', 'MYT', 1, 269);
INSERT INTO countries VALUES (138, 'Mexico', 'MX', 'MEX', 1, 52);
INSERT INTO countries VALUES (139, 'Micronesia Federated States of', 'FM', 'FSM', 1, 691);
INSERT INTO countries VALUES (140, 'Moldova Republic of', 'MD', 'MDA', 1, 373);
INSERT INTO countries VALUES (141, 'Monaco', 'MC', 'MCO', 1, 377);
INSERT INTO countries VALUES (142, 'Mongolia', 'MN', 'MNG', 1, 976);
INSERT INTO countries VALUES (143, 'Montserrat', 'MS', 'MSR', 1, 1664);
INSERT INTO countries VALUES (144, 'Morocco', 'MA', 'MAR', 1, 212);
INSERT INTO countries VALUES (145, 'Mozambique', 'MZ', 'MOZ', 1, 258);
INSERT INTO countries VALUES (146, 'Myanmar', 'MM', 'MMR', 1, 95);
INSERT INTO countries VALUES (147, 'Namibia', 'NA', 'NAM', 1, 264);
INSERT INTO countries VALUES (148, 'Nauru', 'NR', 'NRU', 1, 674);
INSERT INTO countries VALUES (149, 'Nepal', 'NP', 'NPL', 1, 977);
INSERT INTO countries VALUES (150, 'Netherlands', 'NL', 'NLD', 1, 31);
INSERT INTO countries VALUES (151, 'Netherlands Antilles', 'AN', 'ANT', 1, 599);
INSERT INTO countries VALUES (152, 'New Caledonia', 'NC', 'NCL', 1, 687);
INSERT INTO countries VALUES (153, 'New Zealand', 'NZ', 'NZL', 1, 64);
INSERT INTO countries VALUES (154, 'Nicaragua', 'NI', 'NIC', 1, 505);
INSERT INTO countries VALUES (155, 'Niger', 'NE', 'NER', 1, 227);
INSERT INTO countries VALUES (156, 'Nigeria', 'NG', 'NGA', 1, 234);
INSERT INTO countries VALUES (157, 'Niue', 'NU', 'NIU', 1, 683);
INSERT INTO countries VALUES (158, 'Norfolk Island', 'NF', 'NFK', 1, 672);
INSERT INTO countries VALUES (159, 'Northern Mariana Islands', 'MP', 'MNP', 1, 1670);
INSERT INTO countries VALUES (160, 'Norway', 'NO', 'NOR', 1, 47);
INSERT INTO countries VALUES (161, 'Oman', 'OM', 'OMN', 1, 968);
INSERT INTO countries VALUES (162, 'Pakistan', 'PK', 'PAK', 1, 92);
INSERT INTO countries VALUES (163, 'Palau', 'PW', 'PLW', 1, 680);
INSERT INTO countries VALUES (164, 'Panama', 'PA', 'PAN', 1, 507);
INSERT INTO countries VALUES (165, 'Papua New Guinea', 'PG', 'PNG', 1, 675);
INSERT INTO countries VALUES (166, 'Paraguay', 'PY', 'PRY', 1, 595);
INSERT INTO countries VALUES (167, 'Peru', 'PE', 'PER', 1, 51);
INSERT INTO countries VALUES (168, 'Philippines', 'PH', 'PHL', 1, 63);
INSERT INTO countries VALUES (169, 'Pitcairn', 'PN', 'PCN', 1, 872);
INSERT INTO countries VALUES (170, 'Poland', 'PL', 'POL', 1, 48);
INSERT INTO countries VALUES (171, 'Portugal', 'PT', 'PRT', 1, 351);
INSERT INTO countries VALUES (172, 'Puerto Rico', 'PR', 'PRI', 1, 787);
INSERT INTO countries VALUES (173, 'Qatar', 'QA', 'QAT', 1, 974);
INSERT INTO countries VALUES (174, 'Reunion', 'RE', 'REU', 1, 262);
INSERT INTO countries VALUES (175, 'Romania', 'RO', 'ROM', 1, 40);
INSERT INTO countries VALUES (176, 'Russian Federation', 'RU', 'RUS', 1, 7);
INSERT INTO countries VALUES (177, 'Rwanda', 'RW', 'RWA', 1, 250);
INSERT INTO countries VALUES (178, 'Saint Kitts and Nevis', 'KN', 'KNA', 1, 1869);
INSERT INTO countries VALUES (179, 'Saint Lucia', 'LC', 'LCA', 1, 1758);
INSERT INTO countries VALUES (180, 'Saint Vincent and the Grenadines', 'VC', 'VCT', 1, 1784);
INSERT INTO countries VALUES (181, 'Samoa', 'WS', 'WSM', 1, 685);
INSERT INTO countries VALUES (182, 'San Marino', 'SM', 'SMR', 1, 378);
INSERT INTO countries VALUES (183, 'Sao Tome and Principe', 'ST', 'STP', 1, 239);
INSERT INTO countries VALUES (184, 'Saudi Arabia', 'SA', 'SAU', 1, 966);
INSERT INTO countries VALUES (241, 'Senegal', 'SN', 'SEN', 1, 221);
INSERT INTO countries VALUES (185, 'Serbia and Montenegro', 'CS', 'SCG', 1, 381);
INSERT INTO countries VALUES (186, 'Seychelles', 'SC', 'SYC', 1, 248);
INSERT INTO countries VALUES (187, 'Sierra Leone', 'SL', 'SLE', 1, 232);
INSERT INTO countries VALUES (188, 'Singapore', 'SG', 'SGP', 4, 65);
INSERT INTO countries VALUES (189, 'Slovakia (Slovak Republic)', 'SK', 'SVK', 1, 421);
INSERT INTO countries VALUES (190, 'Slovenia', 'SI', 'SVN', 1, 386);
INSERT INTO countries VALUES (191, 'Solomon Islands', 'SB', 'SLB', 1, 677);
INSERT INTO countries VALUES (192, 'Somalia', 'SO', 'SOM', 1, 252);
INSERT INTO countries VALUES (193, 'South Africa', 'ZA', 'ZAF', 1, 27);
INSERT INTO countries VALUES (194, 'South Georgia and the South Sandwich Islands', 'GS', 'SGS', 1, 0);
INSERT INTO countries VALUES (195, 'Spain', 'ES', 'ESP', 3, 34);
INSERT INTO countries VALUES (196, 'Sri Lanka', 'LK', 'LKA', 1, 94);
INSERT INTO countries VALUES (197, 'St. Helena', 'SH', 'SHN', 1, 290);
INSERT INTO countries VALUES (198, 'St. Pierre and Miquelon', 'PM', 'SPM', 1, 508);
INSERT INTO countries VALUES (199, 'Sudan', 'SD', 'SDN', 1, 249);
INSERT INTO countries VALUES (200, 'Suriname', 'SR', 'SUR', 1, 597);
INSERT INTO countries VALUES (201, 'Svalbard and Jan Mayen Islands', 'SJ', 'SJM', 1, 47);
INSERT INTO countries VALUES (202, 'Swaziland', 'SZ', 'SWZ', 1, 268);
INSERT INTO countries VALUES (203, 'Sweden', 'SE', 'SWE', 1, 46);
INSERT INTO countries VALUES (204, 'Switzerland', 'CH', 'CHE', 1, 41);
INSERT INTO countries VALUES (205, 'Syrian Arab Republic', 'SY', 'SYR', 1, 963);
INSERT INTO countries VALUES (206, 'Taiwan', 'TW', 'TWN', 1, 886);
INSERT INTO countries VALUES (207, 'Tajikistan', 'TJ', 'TJK', 1, 7);
INSERT INTO countries VALUES (208, 'Tanzania United Republic of', 'TZ', 'TZA', 1, 255);
INSERT INTO countries VALUES (209, 'Thailand', 'TH', 'THA', 1, 66);
INSERT INTO countries VALUES (210, 'Togo', 'TG', 'TGO', 1, 228);
INSERT INTO countries VALUES (211, 'Tokelau', 'TK', 'TKL', 1, 690);
INSERT INTO countries VALUES (212, 'Tonga', 'TO', 'TON', 1, 676);
INSERT INTO countries VALUES (213, 'Trinidad and Tobago', 'TT', 'TTO', 1, 1868);
INSERT INTO countries VALUES (214, 'Tunisia', 'TN', 'TUN', 1, 216);
INSERT INTO countries VALUES (215, 'Turkey', 'TR', 'TUR', 1, 90);
INSERT INTO countries VALUES (216, 'Turkmenistan', 'TM', 'TKM', 1, 993);
INSERT INTO countries VALUES (217, 'Turks and Caicos Islands', 'TC', 'TCA', 1, 1649);
INSERT INTO countries VALUES (218, 'Tuvalu', 'TV', 'TUV', 1, 688);
INSERT INTO countries VALUES (219, 'Uganda', 'UG', 'UGA', 1, 256);
INSERT INTO countries VALUES (220, 'Ukraine', 'UA', 'UKR', 1, 380);
INSERT INTO countries VALUES (221, 'United Arab Emirates', 'AE', 'ARE', 1, 971);
INSERT INTO countries VALUES (222, 'United Kingdom', 'GB', 'GBR', 1, 44);
INSERT INTO countries VALUES (223, 'United States', 'US', 'USA', 2, 1);
INSERT INTO countries VALUES (224, 'United States Minor Outlying Islands', 'UM', 'UMI', 1, 0);
INSERT INTO countries VALUES (225, 'Uruguay', 'UY', 'URY', 1, 598);
INSERT INTO countries VALUES (226, 'Uzbekistan', 'UZ', 'UZB', 1, 7);
INSERT INTO countries VALUES (227, 'Vanuatu', 'VU', 'VUT', 1, 678);
INSERT INTO countries VALUES (228, 'Vatican City State (Holy See)', 'VA', 'VAT', 1, 39);
INSERT INTO countries VALUES (229, 'Venezuela', 'VE', 'VEN', 1, 58);
INSERT INTO countries VALUES (230, 'Viet Nam', 'VN', 'VNM', 1, 84);
INSERT INTO countries VALUES (231, 'Virgin Islands (British)', 'VG', 'VGB', 1, 284);
INSERT INTO countries VALUES (232, 'Virgin Islands (U.S.)', 'VI', 'VIR', 1, 340);
INSERT INTO countries VALUES (233, 'Wallis and Futuna Islands', 'WF', 'WLF', 1, 681);
INSERT INTO countries VALUES (234, 'Western Sahara', 'EH', 'ESH', 1, 685);
INSERT INTO countries VALUES (235, 'Yemen', 'YE', 'YEM', 1, 967);
INSERT INTO countries VALUES (236, 'Yugoslavia', 'YU', 'YUG', 1, 381);
INSERT INTO countries VALUES (237, 'Zaire', 'ZR', 'ZAR', 1, 243);
INSERT INTO countries VALUES (238, 'Zambia', 'ZM', 'ZMB', 1, 260);
INSERT INTO countries VALUES (239, 'Zimbabwe', 'ZW', 'ZWE', 1, 263);

INSERT INTO currencies VALUES (8,'Euro','EUR','?','','.',',','2',0.61559999,'2005-08-09 20:37:20');
INSERT INTO currencies VALUES (7,'United States Dollar','USD','$','','.',',','2',0.76130003,'2005-08-09 20:37:20');
INSERT INTO currencies VALUES (6,'Australian Dollar','AUD','$','','.',',','2',1.00000000,'2005-08-09 20:37:20');
INSERT INTO currencies VALUES (9,'UK Pound','GBP','�','','.',',','2',0.42609999,'2005-08-09 20:37:20');


INSERT INTO customers_info VALUES('1', '', '0', now(), '', '0');

INSERT INTO languages VALUES (1,'English','en','icon.jpg','english',1);

INSERT INTO orders_status VALUES ( '1', '1', 'Pending');
INSERT INTO orders_status VALUES ( '2', '1', 'Processing');
INSERT INTO orders_status VALUES ( '3', '1', 'Delivered');

# multiple image
ALTER TABLE products CHANGE products_image products_image_1 VARCHAR(64);

ALTER TABLE products ADD products_image_2 VARCHAR(64);
ALTER TABLE products ADD products_image_3 VARCHAR(64);
ALTER TABLE products ADD products_image_4 VARCHAR(64);
ALTER TABLE products ADD products_image_5 VARCHAR(64);
ALTER TABLE products ADD products_title_1 VARCHAR(100);
ALTER TABLE products ADD products_title_2 VARCHAR(100);
ALTER TABLE products ADD products_title_3 VARCHAR(100);
ALTER TABLE products ADD products_title_4 VARCHAR(100);
ALTER TABLE products ADD products_title_5 VARCHAR(100); 

INSERT INTO products VALUES (6,100,'','navy_blue_10_cap.jpg','30.0000','2005-09-16 23:39:08','2005-09-17 01:03:42',now(),'0.20',1,2,0,0,'','','','','Blue 10 Cap','','','','');
INSERT INTO products VALUES (7,100,'','larger_than_life.jpg','23.3200','2005-09-16 23:44:19','2005-09-17 00:47:33',now(),'0.20',1,2,0,0,'','','','','Larger than Life CD','','','','');
INSERT INTO products VALUES (3,100,'','alb_tenology.jpg','28.0000','2005-09-16 22:57:39','2005-09-17 00:54:14',now(),'0.20',1,2,0,0,'','','','',' Tenology CD','','','','');
INSERT INTO products VALUES (4,100,'','colours_video.jpg','40.0000','2005-09-16 23:11:53','2005-09-17 00:58:45',now(),'0.30',1,2,0,0,'','','','','Colours - The Video','','','','');
INSERT INTO products VALUES (5,100,'','t_shirt.jpg','36.3600','2005-09-16 23:22:13','2005-09-17 01:14:39',now(),'0.30',1,2,0,0,'','','','','Signed T-Shirt','','','','');
INSERT INTO products VALUES (8,100,'','ten_tenors.jpg','26.3200','2005-09-17 00:05:38','2005-09-17 00:49:29',now(),'0.20',1,2,0,0,'','','','','Ten Tenors CD','','','','');
INSERT INTO products VALUES (9,100,'','stubby_holder.jpg','6.5000','2005-09-17 00:10:40',NULL,now(),'0.10',1,2,0,0,'','','','','Stubby Holder','','','','');
INSERT INTO products VALUES (10,100,'','larger_than_life.jpg','30.4000','2005-09-17 00:14:43','2005-09-17 01:00:24','2010-01-01 00:00:00','0.20',1,2,0,0,'','','','','Larger Than Life DVD','','','','');
INSERT INTO products VALUES (11,100,'','untied.jpg','26.3200','2005-09-17 00:23:43','2005-09-17 00:55:22',now(),'0.20',1,2,0,0,'','','','','Untied CD','','','','');
INSERT INTO products VALUES (12,100,'','colours.jpg','26.3200','2005-09-17 00:24:54','2005-09-17 00:45:37',now(),'0.20',1,2,0,0,'','','','','Colours CD','','','','');
INSERT INTO products VALUES (13,100,'','tennorissimo.jpg','26.3200','2005-09-17 00:26:18','2005-09-17 00:51:13',now(),'0.20',1,2,0,0,'','','','','Tennorissimo CD','','','','');
INSERT INTO products VALUES (14,100,'','poster.jpg','30.0000','2005-09-17 01:11:50',NULL,now(),'0.20',1,2,0,0,'','','','','Signed Poster - Larger Than Life','','','','');

INSERT INTO products_description VALUES (1,1,'Tenology','<!--StartFragment -->&nbsp;<STRONG>Track Listings</STRONG><BR>\r\n<TABLE cellSpacing=0 cellPadding=0 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD vAlign=top width=\"50%\"><FONT style=\"FONT: 11pt/16pt Arial,Helvetica; font-size-adjust: none; font-stretch: normal\">1. Water / Va Pensiero<BR>2. Italian Medley <BR>3. World Anthem <BR>4. The Way Away From You <BR>5. Sundance <BR>6. Stonde <BR>7. Mama <BR>8. Por una Cabeza <BR>9. Conquest of Paradise <BR>10. Cast In Stone <BR>11. Veni, Veni Emmanuel <BR></FONT></TD>\r\n<TD width=\"5%\"></TD>\r\n<TD vAlign=top width=\"45%\"><FONT style=\"FONT: 11pt/16pt Arial,Helvetica; font-size-adjust: none; font-stretch: normal\"><STRONG>Bonus Tracks</STRONG><BR>1. Opera Without the Boring Bits (live) <BR>2. Bohemian Rhapsody (live) <BR>3. Bicycle Race <BR></FONT></TD></TR></TBODY></TABLE><STRONG>Other Details<BR></STRONG><FONT style=\"FONT: 10pt/16pt Arial,Helvetica; font-size-adjust: none; font-stretch: normal\">- Compilation album featuring tracks from Colours, unTied, <BR>One is not enough and Larger than Life<BR>- Released in Australia July 29, 2005</FONT>','',0);
INSERT INTO products_description VALUES (2,1,'Tenology','<!--StartFragment --><STRONG>&nbsp;Track Listings</STRONG><BR>\r\n<TABLE cellSpacing=0 cellPadding=0 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD vAlign=top width=\"50%\"><FONT style=\"FONT: 11pt/16pt Arial,Helvetica; font-size-adjust: none; font-stretch: normal\">1. Water / Va Pensiero<BR>2. Italian Medley <BR>3. World Anthem <BR>4. The Way Away From You <BR>5. Sundance <BR>6. Stonde <BR>7. Mama <BR>8. Por una Cabeza <BR>9. Conquest of Paradise <BR>10. Cast In Stone <BR>11. Veni, Veni Emmanuel <BR></FONT></TD>\r\n<TD width=\"5%\"></TD>\r\n<TD vAlign=top width=\"45%\"><FONT style=\"FONT: 11pt/16pt Arial,Helvetica; font-size-adjust: none; font-stretch: normal\"><STRONG>Bonus Tracks</STRONG><BR>1. Opera Without the Boring Bits (live) <BR>2. Bohemian Rhapsody (live) <BR>3. Bicycle Race <BR></FONT></TD></TR></TBODY></TABLE><STRONG>Other Details</STRONG><BR><FONT style=\"FONT: 10pt/16pt Arial,Helvetica; font-size-adjust: none; font-stretch: normal\">- Compilation album featuring tracks from Colours, unTied, <BR>One is not enough and Larger than Life<BR>- Released in Australia July 29, 2005</FONT>','',0);
INSERT INTO products_description VALUES (3,1,'Tenology CD','<P><FONT size=1></FONT><FONT size=1>Featuring a selection of The Ten Tenors favourites and original pieces from their previously released albums (Colours, unTied, One Is Not Enough, Larger Than Life). The album also features three bonus tracks, including their version of Queen�??s classic song �??Bicycle Race�?? that was specifically chosen by a German Television Network to coincide with their 2004 Tour de France coverage. </FONT></P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD width=\"50%\"><FONT size=1>1. Water / Va Pensiero<BR>2. Italian Medley:<BR>&nbsp;&nbsp;&nbsp; Mattinata<BR>&nbsp;&nbsp;&nbsp; Santa Lucia <BR>&nbsp;&nbsp;&nbsp; Volare (Nel blu di pinto di blu)<BR>3. World Anthem<BR>4. The Way Away From You<BR>5. Sundance<BR>6. Stonde<BR>7. Mama<BR>8. Por una Cabeza<BR>9. Conquest of Paradise<BR>10. Cast In Stone<BR>11. Veni Veni Emmanuel<BR><STRONG>Bonus Tracks<BR></STRONG>1. Opera Without the Boring Bits (live):<BR>&nbsp;&nbsp;&nbsp; La donna é mobile<BR>&nbsp;&nbsp;&nbsp; Che gelida manina<BR>&nbsp;&nbsp;&nbsp; Va Pensiero<BR>&nbsp;&nbsp;&nbsp; Largo al factotum<BR>2. Bohemian Rhapsody (live)<BR>3. Bicycle Race<BR>Total playing time ~ 54.30 </FONT><FONT style=\"FONT: 11pt/16pt Arial,Helvetica; font-size-adjust: none; font-stretch: normal\">&nbsp;</FONT><FONT size=1> \r\n<P>&nbsp;</P></FONT>\r\n<P></P></FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>','',12);
INSERT INTO products_description VALUES (4,1,'Colours - The Video','<P><FONT size=1></FONT><FONT size=1><FONT size=1>The Ten Tenors 3rd album. Released in 2000. Features 10 Tenors originals and other Australian favourites.</FONT></FONT></P>\r\n<P><FONT size=1><B>Please note that this VHS is only available in PAL format</B><BR>Last copies of \"Colours - The Video\" available internationally. Hurry before they are all sold.</FONT></P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD width=\"50%\"><FONT size=1>1. Funiculi, Funicula<BR>2. Mama<BR>3. Girls Where Made to Love and Kiss <BR>4. The Colour of Your Voice<BR>5. Stayin\' Alive<BR>6. Intalian Mediley<BR>7. Rawhide<BR>8. Memory (Cats)<BR>9. New York, New York<BR>10. Brindisi (La Traviata)<BR>11. Musical Theatre Medley<BR>12. Bridge Over Troubled Water<BR>13. Music of the Night (Phantom of the Opera)<BR>14. French Opera Medley<BR>15. That\'s Amore<BR>16. Nussum dorma! (Turandot)<BR>17. Danny Boy<BR>18. O Sole Mio</FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>\r\n<P>&nbsp;</P>\r\n<P>&nbsp;</P>','',5);
INSERT INTO products_description VALUES (5,1,'Signed T-Shirt','<P>&nbsp;</P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD vAlign=top width=\"50%\"><FONT size=1>\r\n<P>\r\n<P><B><FONT size=1>Limited number of Signed T-shirts - Hurry, while stocks \r\nlast!</FONT></B></P>\r\n<P><FONT size=1>This 100% cotton (pre-shrunk) t-shirt, with The Ten Tenors logo \r\non both front and back has been signed by Dion Molinas, Liam McLachlan, David \r\nKidd, Craig Atkinson, Stewart Morris, Tod Strike, Jason Turnbull, Craig Hendry, \r\nShannon Brown &amp; Drew Graham.<BR><BR>Please note: As there are so few left \r\nand these are signed items, there will be no returns for incorrect size \r\nselection.</FONT> </P>\r\n<P></P></FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>','',11);
INSERT INTO products_description VALUES (6,1,'Blue 10 Cap','<P>&nbsp;</P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD vAlign=top width=\"50%\"><FONT size=1>\r\n<P>This navy blue cap featuring The Ten Tenors \'10\' logo is the last remaining stock from their Spring 2005 USA tour. There are two \'flexifit\' sizes available. Numbers are limited so order while stocks last. </P></FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>','',5);
INSERT INTO products_description VALUES (7,1,'Larger than Life CD','<P><FONT size=1> Larger than Life features orginal music written especially for \r\n  The Ten Tenors, Ten Tenors orginals and includes a bonus \'live\' CD.</FONT></P>\r\n<table width=\"100%\" border=\"0\" cellpadding=\"5\">\r\n  <tr>\r\n    <td width=\"50%\"><FONT size=1>1. Water / Va Pensiero <BR>\r\n      2. Stonde <BR>\r\n      3. The Way Away From You <BR>\r\n      4. Angel <BR>\r\n      5. Por Una Cabeza <BR>\r\n      6. Together <BR>\r\n      7. Feet Lift Off The Ground <BR>\r\n      8. Cast In Stone <BR>\r\n      9. Sundance <BR>\r\n      10. World Anthem <BR>\r\n      11. Destiny Lies <BR>\r\n      12. Thunder Point <BR>\r\n      13. Burn for you <BR>\r\n      14. Conquest of Paradise <BR>\r\n      15. Bicycle Race <BR>\r\n      <BR>\r\n      Bonus Live CD <BR>\r\n      1.Funiculi Funicula <BR>\r\n      2. Granada <BR>\r\n      3. Bohemian Rhapsody <BR>\r\n      4. Bee Gees Medley <BR>\r\n      5. Opera Medley <BR>\r\n      6. Dancing Queen</FONT></td>\r\n    <td width=\"50%\" align=\"right\" valign=\"top\"></td>\r\n  </tr>\r\n</table>\r\n<P> <FONT size=1><B>Upgrade to the Special Edition for only A$3.00 extra, and \r\n  receive a bonus 7th track with the Ralph Siegel Medley</B></FONT> </P>','',9);
INSERT INTO products_description VALUES (8,1,'Ten Tenors CD','<P><FONT size=1><STRONG>Special European version of Larger than Life</STRONG></FONT></P>\r\n<P><FONT size=1>Larger than Life features orginal music written especially for The Ten Tenors, Ten Tenors orginals and includes a bonus \'live\' CD which includes the Ralph Siegel Medley.</FONT></P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD width=\"50%\"><FONT size=1>\r\n<P>1<FONT size=1>. Water / Va Pensiero <BR>2. Stonde <BR>3. The Way Away From You <BR>4. Angel <BR>5. Por Una Cabeza <BR>6. Together <BR>7. Feet Lift Off The Ground <BR>8. Cast In Stone <BR>9. Sundance <BR>10. World Anthem <BR>11. Destiny Lies <BR>12. Thunder Point <BR>13. Burn for you <BR>14. Conquest of Paradise <BR>15. Bicycle Race <BR><BR>Bonus Live CD <BR>1.Funiculi Funicula <BR>2. Granada <BR>3. Bohemian Rhapsody <BR>4. Bee Gees Medley <BR>5. Opera Medley <BR>6. Dancing Queen <BR>7. Ralph Siegel Medley</FONT></P></FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>','',1);
INSERT INTO products_description VALUES (9,1,'Stubby Holder','<!--StartFragment --><FONT size=1>&nbsp;Ten Tenors \'stubbie cooler\' for keeping drinks cool</FONT>','',4);
INSERT INTO products_description VALUES (10,1,'Larger Than Life DVD','<P><FONT size=1> </FONT><FONT size=1><font size=1><b>Multi-regional (international) \r\n  format</b><br>\r\n  Classically trained tenors encouraging the audience to act like football fans? \r\n  That�??s right! The entertaining public television special THE TEN TENORS: LARGER \r\n  THAN LIFE is a one-of-a-kind performance showcasing the group�??s range and abilities. \r\n  The program features the cast of ten energetic and talented Australian tenors \r\n  who blend music and a sense of humour to produce a unique concert experience.</font></FONT></P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n  <TBODY>\r\n<TR>\r\n<TD width=\"50%\"><FONT size=1>\r\n        <P><FONT size=1>1. Funiculi Funicula <BR>\r\n          2. Italian medley:<BR>\r\n          &nbsp;&nbsp;&nbsp; Torna Surriento<BR>\r\n          &nbsp;&nbsp;&nbsp; La Danza<BR>\r\n          &nbsp;&nbsp;&nbsp; Core�?? ngrato<BR>\r\n          &nbsp;&nbsp;&nbsp; Volare<BR>\r\n          3. Thunder Point <BR>\r\n          4. Nessun Dorma <BR>\r\n          5. Por una Cabeza <BR>\r\n          6. Opera medley:<BR>\r\n          &nbsp;&nbsp;&nbsp; La Donna é Mobile (Rigoletto)<BR>\r\n          &nbsp;&nbsp;&nbsp; Che Gelida Manina (La Boheme)<BR>\r\n          &nbsp;&nbsp;&nbsp; Va Pensiero (Nabucco)<BR>\r\n          &nbsp;&nbsp;&nbsp; Largo al Factotum (The Barber of Seville) <BR>\r\n          7. Conquest of Paradise <BR>\r\n          8. Stonde <BR>\r\n          9. Water/Va Pensiero <BR>\r\n          10. Australian medley: Botany Bay; Moreton Bay; Waltzing Matilda<BR>\r\n          11. Rawhide <BR>\r\n          <BR>\r\n          Filmed at the Lyric Theatre, Queensland Performing Arts Complex, Brisbane, \r\n          Australia, 21 April, 2004. <BR>\r\n          Multi-regional (international) format</FONT></P>\r\n</FONT></TD>\r\n      <TD width=\"50%\" align=\"right\" valign=\"top\"></TD>\r\n    </TR></TBODY></TABLE>\r\n<P>&nbsp;</P>\r\n<P>&nbsp;</P>','',3);
INSERT INTO products_description VALUES (11,1,'Untied CD','<P><FONT size=1></FONT><FONT size=1><FONT size=1>The Ten Tenors 3rd album. Released in 2000. Features 10 Tenors originals and other Australian favourites.</FONT></FONT></P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD width=\"50%\"><FONT size=1>\r\n<P><FONT size=1>1. Rocket<BR>2. What Am I Waiting For?<BR>3. Bohemian Rhapsody <BR>4. Darlinghurst Road <BR>5. My Daughter <BR>6. Because of you <BR>7. Throw Your Arms Around Me <BR>8. Where do I go? <BR>9. Never (Just A Memory) <BR>10. Dancing Queen <BR>11. Australian Medley</FONT></P>\r\n<P>&nbsp;</P></FONT>\r\n<P></P></FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>','',3);
INSERT INTO products_description VALUES (12,1,'Colours CD','<P><FONT size=1>The Ten Tenors 2nd Album. Released in 1999. Featuring mix of well known songs from musicals, and contempory classics. </FONT></P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n<TD width=\"50%\"><FONT size=1>1. Mama <BR>2. Italian Medley <BR>3. The Colour of Your Voice <BR>4. My Heart and I <BR>5. Irish Medley <BR>6. The Way You Look Tonight <BR>7. Sit Down, You\'re Rockin\' the Boat <BR>8. Musical Medley <BR>9. New York, New York <BR>10. Lullabye (Goodnight, My Angel) <BR>11. Bridge Over Troubled Water <BR>12. Rawhide <BR>13. Stayin\' Alive <BR>14. A Short Lesson In Opera <BR>15. Opera Medley</FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>\r\n<P><FONT size=1></FONT></P>\r\n<P>&nbsp;</P>','',4);
INSERT INTO products_description VALUES (13,1,'Tennorissimo CD','<P><FONT size=1> <font size=1>The Ten Tenors Debut Album. Released in 1998 . \r\n  Featuring a mix of opera favourite and tradional classics.</font> </FONT><font size=1>.</font></P>\r\n<table width=\"100%\" border=\"0\" cellpadding=\"5\">\r\n  <tr>\r\n    <td width=\"50%\"><FONT size=1> \r\n      <P><FONT size=1>1. Funiculi Funicula <BR>2. You Are My Hearts Delight <BR>3. \r\nGranada <BR>4. La Donna e Mobile <BR>5. Nessun Dorma <BR>6. Torna a Surriento \r\n<BR>7. O Sole Mio <BR>8. Girls Were Made To Love And Kiss <BR>9. Memory <BR>10. \r\nStranger In Paradise <BR>11. Love Changes Everything <BR>12. Danny Boy <BR>13. \r\nMusical Medley <BR>14. That\'s Amore <BR>15. Calypso (Bonus Track)</FONT></P></FONT></P>\r\n</FONT></td>\r\n    <td width=\"50%\" align=\"right\" valign=\"top\"></td>\r\n  </tr>\r\n</table>','',2);
INSERT INTO products_description VALUES (14,1,'Signed Poster - Larger Than Life','<P>&nbsp;</P>\r\n<TABLE cellPadding=5 width=\"100%\" border=0>\r\n<TBODY>\r\n<TR>\r\n      <TD vAlign=top width=\"50%\"><FONT size=1> \r\n        <P> \r\n        <P><B><FONT size=1>Limited number of Signed Posters - Hurry, while stocks \r\n          last!</FONT></B></P>\r\n        <P>This rare, collectable 2004 tour poster has been autographed by Liam \r\n          McLachlan, Tod Strike, Dion Molinas, Craig Atkinson, Craig Hendry, Stewart \r\n          Morris, Shannon Brown, David Kidd, Drew Graham, and Dom Smith. </P></P>\r\n        </FONT></TD>\r\n<TD vAlign=top align=right width=\"50%\"></TD></TR></TBODY></TABLE>','',4);

INSERT INTO products_attributes VALUES (5,5,1,1,'0.0000','+',1,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (7,5,1,3,'0.0000','+',3,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (8,5,1,4,'0.0000','+',4,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (6,5,1,2,'0.0000','+',2,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (9,6,1,1,'0.0000','',0,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (10,6,1,2,'0.0000','',0,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (11,6,1,3,'0.0000','',0,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (12,7,2,5,'3.0000','+',1,0,'0.00','',0,'0.0000');
INSERT INTO products_attributes VALUES (13,7,2,6,'0.0000','+',2,0,'0.00','',0,'0.0000');


INSERT INTO products_attributes_download VALUES (26, 'unreal.zip', 7, 3);

INSERT INTO products_options VALUES (1,1,'Size',1);
INSERT INTO products_options VALUES (2,1,'Special Edition CD',2);


INSERT INTO products_options_values VALUES (1,1,'Small');
INSERT INTO products_options_values VALUES (2,1,'Medium');
INSERT INTO products_options_values VALUES (3,1,'Large');
INSERT INTO products_options_values VALUES (4,1,'Extra Large');
INSERT INTO products_options_values VALUES (5,1,'Upgrade');
INSERT INTO products_options_values VALUES (6,1,'Not Required');


INSERT INTO products_options_values_to_products_options VALUES (1,1,1);
INSERT INTO products_options_values_to_products_options VALUES (2,1,2);
INSERT INTO products_options_values_to_products_options VALUES (3,1,3);
INSERT INTO products_options_values_to_products_options VALUES (4,1,4);
INSERT INTO products_options_values_to_products_options VALUES (5,2,5);
INSERT INTO products_options_values_to_products_options VALUES (6,2,6);


INSERT INTO products_to_categories VALUES (3,1);
INSERT INTO products_to_categories VALUES (4,2);
INSERT INTO products_to_categories VALUES (5,3);
INSERT INTO products_to_categories VALUES (6,3);
INSERT INTO products_to_categories VALUES (7,1);
INSERT INTO products_to_categories VALUES (8,1);
INSERT INTO products_to_categories VALUES (9,4);
INSERT INTO products_to_categories VALUES (10,2);
INSERT INTO products_to_categories VALUES (11,1);
INSERT INTO products_to_categories VALUES (12,1);
INSERT INTO products_to_categories VALUES (13,1);
INSERT INTO products_to_categories VALUES (14,4);


INSERT INTO tax_class VALUES (2,'GST','Australian Goods and Services Tax',NULL,'2004-02-20 23:16:40');
INSERT INTO tax_class VALUES (3,'CST','California Services Tax',NULL,'2004-02-20 23:16:40');

INSERT INTO tax_rates VALUES (2,3,2,0,'10.0000','Australian Goods and Services Tax','2005-07-06 21:30:35','2004-02-20 23:17:22');

INSERT INTO geo_zones VALUES (1,'USA','United States of America',NULL,'0000-00-00 00:00:00');
INSERT INTO geo_zones VALUES (3,'Australia','Australia Zones',NULL,'0000-00-00 00:00:00'); 
INSERT INTO geo_zones VALUES (2,'World Zones','All International Zones',NULL,'0000-00-00 00:00:00');

INSERT INTO zones VALUES (1,223,'AL','Alabama');
INSERT INTO zones VALUES (2,223,'AK','Alaska');
INSERT INTO zones VALUES (3,223,'AS','American Samoa');
INSERT INTO zones VALUES (4,223,'AZ','Arizona');
INSERT INTO zones VALUES (5,223,'AR','Arkansas');
INSERT INTO zones VALUES (6,223,'AF','Armed Forces Africa');
INSERT INTO zones VALUES (7,223,'AA','Armed Forces Americas');
INSERT INTO zones VALUES (8,223,'AC','Armed Forces Canada');
INSERT INTO zones VALUES (9,223,'AE','Armed Forces Europe');
INSERT INTO zones VALUES (10,223,'AM','Armed Forces Middle East');
INSERT INTO zones VALUES (11,223,'AP','Armed Forces Pacific');
INSERT INTO zones VALUES (12,223,'CA','California');
INSERT INTO zones VALUES (13,223,'CO','Colorado');
INSERT INTO zones VALUES (14,223,'CT','Connecticut');
INSERT INTO zones VALUES (15,223,'DE','Delaware');
INSERT INTO zones VALUES (16,223,'DC','District of Columbia');
INSERT INTO zones VALUES (17,223,'FM','Federated States Of Micronesia');
INSERT INTO zones VALUES (18,223,'FL','Florida');
INSERT INTO zones VALUES (19,223,'GA','Georgia');
INSERT INTO zones VALUES (20,223,'GU','Guam');
INSERT INTO zones VALUES (21,223,'HI','Hawaii');
INSERT INTO zones VALUES (22,223,'ID','Idaho');
INSERT INTO zones VALUES (23,223,'IL','Illinois');
INSERT INTO zones VALUES (24,223,'IN','Indiana');
INSERT INTO zones VALUES (25,223,'IA','Iowa');
INSERT INTO zones VALUES (26,223,'KS','Kansas');
INSERT INTO zones VALUES (27,223,'KY','Kentucky');
INSERT INTO zones VALUES (28,223,'LA','Louisiana');
INSERT INTO zones VALUES (29,223,'ME','Maine');
INSERT INTO zones VALUES (30,223,'MH','Marshall Islands');
INSERT INTO zones VALUES (31,223,'MD','Maryland');
INSERT INTO zones VALUES (32,223,'MA','Massachusetts');
INSERT INTO zones VALUES (33,223,'MI','Michigan');
INSERT INTO zones VALUES (34,223,'MN','Minnesota');
INSERT INTO zones VALUES (35,223,'MS','Mississippi');
INSERT INTO zones VALUES (36,223,'MO','Missouri');
INSERT INTO zones VALUES (37,223,'MT','Montana');
INSERT INTO zones VALUES (38,223,'NE','Nebraska');
INSERT INTO zones VALUES (39,223,'NV','Nevada');
INSERT INTO zones VALUES (40,223,'NH','New Hampshire');
INSERT INTO zones VALUES (41,223,'NJ','New Jersey');
INSERT INTO zones VALUES (42,223,'NM','New Mexico');
INSERT INTO zones VALUES (43,223,'NY','New York');
INSERT INTO zones VALUES (44,223,'NC','North Carolina');
INSERT INTO zones VALUES (45,223,'ND','North Dakota');
INSERT INTO zones VALUES (46,223,'MP','Northern Mariana Islands');
INSERT INTO zones VALUES (47,223,'OH','Ohio');
INSERT INTO zones VALUES (48,223,'OK','Oklahoma');
INSERT INTO zones VALUES (49,223,'OR','Oregon');
INSERT INTO zones VALUES (50,223,'PW','Palau');
INSERT INTO zones VALUES (51,223,'PA','Pennsylvania');
INSERT INTO zones VALUES (52,223,'PR','Puerto Rico');
INSERT INTO zones VALUES (53,223,'RI','Rhode Island');
INSERT INTO zones VALUES (54,223,'SC','South Carolina');
INSERT INTO zones VALUES (55,223,'SD','South Dakota');
INSERT INTO zones VALUES (56,223,'TN','Tennessee');
INSERT INTO zones VALUES (57,223,'TX','Texas');
INSERT INTO zones VALUES (58,223,'UT','Utah');
INSERT INTO zones VALUES (59,223,'VT','Vermont');
INSERT INTO zones VALUES (60,223,'VI','Virgin Islands');
INSERT INTO zones VALUES (61,223,'VA','Virginia');
INSERT INTO zones VALUES (62,223,'WA','Washington');
INSERT INTO zones VALUES (63,223,'WV','West Virginia');
INSERT INTO zones VALUES (64,223,'WI','Wisconsin');
INSERT INTO zones VALUES (65,223,'WY','Wyoming');
INSERT INTO zones VALUES (66,38,'AB','Alberta');
INSERT INTO zones VALUES (67,38,'BC','British Columbia');
INSERT INTO zones VALUES (68,38,'MB','Manitoba');
INSERT INTO zones VALUES (69,38,'NF','Newfoundland');
INSERT INTO zones VALUES (70,38,'NB','New Brunswick');
INSERT INTO zones VALUES (71,38,'NS','Nova Scotia');
INSERT INTO zones VALUES (72,38,'NT','Northwest Territories');
INSERT INTO zones VALUES (73,38,'NU','Nunavut');
INSERT INTO zones VALUES (74,38,'ON','Ontario');
INSERT INTO zones VALUES (75,38,'PE','Prince Edward Island');
INSERT INTO zones VALUES (76,38,'QC','Quebec');
INSERT INTO zones VALUES (77,38,'SK','Saskatchewan');
INSERT INTO zones VALUES (78,38,'YT','Yukon Territory');
INSERT INTO zones VALUES (79,81,'NDS','Niedersachsen');
INSERT INTO zones VALUES (80,81,'BAW','Baden-W�rttemberg');
INSERT INTO zones VALUES (81,81,'BAY','Bayern');
INSERT INTO zones VALUES (82,81,'BER','Berlin');
INSERT INTO zones VALUES (83,81,'BRG','Brandenburg');
INSERT INTO zones VALUES (84,81,'BRE','Bremen');
INSERT INTO zones VALUES (85,81,'HAM','Hamburg');
INSERT INTO zones VALUES (86,81,'HES','Hessen');
INSERT INTO zones VALUES (87,81,'MEC','Mecklenburg-Vorpommern');
INSERT INTO zones VALUES (88,81,'NRW','Nordrhein-Westfalen');
INSERT INTO zones VALUES (89,81,'RHE','Rheinland-Pfalz');
INSERT INTO zones VALUES (90,81,'SAR','Saarland');
INSERT INTO zones VALUES (91,81,'SAS','Sachsen');
INSERT INTO zones VALUES (92,81,'SAC','Sachsen-Anhalt');
INSERT INTO zones VALUES (93,81,'SCN','Schleswig-Holstein');
INSERT INTO zones VALUES (94,81,'THE','Th�ringen');
INSERT INTO zones VALUES (95,14,'WI','Wien');
INSERT INTO zones VALUES (96,14,'NO','Nieder�sterreich');
INSERT INTO zones VALUES (97,14,'OO','Ober�sterreich');
INSERT INTO zones VALUES (98,14,'SB','Salzburg');
INSERT INTO zones VALUES (99,14,'KN','K�rnten');
INSERT INTO zones VALUES (100,14,'ST','Steiermark');
INSERT INTO zones VALUES (101,14,'TI','Tirol');
INSERT INTO zones VALUES (102,14,'BL','Burgenland');
INSERT INTO zones VALUES (103,14,'VB','Voralberg');
INSERT INTO zones VALUES (104,204,'AG','Aargau');
INSERT INTO zones VALUES (105,204,'AI','Appenzell Innerrhoden');
INSERT INTO zones VALUES (106,204,'AR','Appenzell Ausserrhoden');
INSERT INTO zones VALUES (107,204,'BE','Bern');
INSERT INTO zones VALUES (108,204,'BL','Basel-Landschaft');
INSERT INTO zones VALUES (109,204,'BS','Basel-Stadt');
INSERT INTO zones VALUES (110,204,'FR','Freiburg');
INSERT INTO zones VALUES (111,204,'GE','Genf');
INSERT INTO zones VALUES (112,204,'GL','Glarus');
INSERT INTO zones VALUES (113,204,'JU','Graub�nden');
INSERT INTO zones VALUES (114,204,'JU','Jura');
INSERT INTO zones VALUES (115,204,'LU','Luzern');
INSERT INTO zones VALUES (116,204,'NE','Neuenburg');
INSERT INTO zones VALUES (117,204,'NW','Nidwalden');
INSERT INTO zones VALUES (118,204,'OW','Obwalden');
INSERT INTO zones VALUES (119,204,'SG','St. Gallen');
INSERT INTO zones VALUES (120,204,'SH','Schaffhausen');
INSERT INTO zones VALUES (121,204,'SO','Solothurn');
INSERT INTO zones VALUES (122,204,'SZ','Schwyz');
INSERT INTO zones VALUES (123,204,'TG','Thurgau');
INSERT INTO zones VALUES (124,204,'TI','Tessin');
INSERT INTO zones VALUES (125,204,'UR','Uri');
INSERT INTO zones VALUES (126,204,'VD','Waadt');
INSERT INTO zones VALUES (127,204,'VS','Wallis');
INSERT INTO zones VALUES (128,204,'ZG','Zug');
INSERT INTO zones VALUES (129,204,'ZH','Z�rich');
INSERT INTO zones VALUES (130,195,'A Coru�a','A Coru�a');
INSERT INTO zones VALUES (131,195,'Alava','Alava');
INSERT INTO zones VALUES (132,195,'Albacete','Albacete');
INSERT INTO zones VALUES (133,195,'Alicante','Alicante');
INSERT INTO zones VALUES (134,195,'Almeria','Almeria');
INSERT INTO zones VALUES (135,195,'Asturias','Asturias');
INSERT INTO zones VALUES (136,195,'Avila','Avila');
INSERT INTO zones VALUES (137,195,'Badajoz','Badajoz');
INSERT INTO zones VALUES (138,195,'Baleares','Baleares');
INSERT INTO zones VALUES (139,195,'Barcelona','Barcelona');
INSERT INTO zones VALUES (140,195,'Burgos','Burgos');
INSERT INTO zones VALUES (141,195,'Caceres','Caceres');
INSERT INTO zones VALUES (142,195,'Cadiz','Cadiz');
INSERT INTO zones VALUES (143,195,'Cantabria','Cantabria');
INSERT INTO zones VALUES (144,195,'Castellon','Castellon');
INSERT INTO zones VALUES (145,195,'Ceuta','Ceuta');
INSERT INTO zones VALUES (146,195,'Ciudad Real','Ciudad Real');
INSERT INTO zones VALUES (147,195,'Cordoba','Cordoba');
INSERT INTO zones VALUES (148,195,'Cuenca','Cuenca');
INSERT INTO zones VALUES (149,195,'Girona','Girona');
INSERT INTO zones VALUES (150,195,'Granada','Granada');
INSERT INTO zones VALUES (151,195,'Guadalajara','Guadalajara');
INSERT INTO zones VALUES (152,195,'Guipuzcoa','Guipuzcoa');
INSERT INTO zones VALUES (153,195,'Huelva','Huelva');
INSERT INTO zones VALUES (154,195,'Huesca','Huesca');
INSERT INTO zones VALUES (155,195,'Jaen','Jaen');
INSERT INTO zones VALUES (156,195,'La Rioja','La Rioja');
INSERT INTO zones VALUES (157,195,'Las Palmas','Las Palmas');
INSERT INTO zones VALUES (158,195,'Leon','Leon');
INSERT INTO zones VALUES (159,195,'Lleida','Lleida');
INSERT INTO zones VALUES (160,195,'Lugo','Lugo');
INSERT INTO zones VALUES (161,195,'Madrid','Madrid');
INSERT INTO zones VALUES (162,195,'Malaga','Malaga');
INSERT INTO zones VALUES (163,195,'Melilla','Melilla');
INSERT INTO zones VALUES (164,195,'Murcia','Murcia');
INSERT INTO zones VALUES (165,195,'Navarra','Navarra');
INSERT INTO zones VALUES (166,195,'Ourense','Ourense');
INSERT INTO zones VALUES (167,195,'Palencia','Palencia');
INSERT INTO zones VALUES (168,195,'Pontevedra','Pontevedra');
INSERT INTO zones VALUES (169,195,'Salamanca','Salamanca');
INSERT INTO zones VALUES (170,195,'Santa Cruz de Tenerife','Santa Cruz de Tenerife');
INSERT INTO zones VALUES (171,195,'Segovia','Segovia');
INSERT INTO zones VALUES (172,195,'Sevilla','Sevilla');
INSERT INTO zones VALUES (173,195,'Soria','Soria');
INSERT INTO zones VALUES (174,195,'Tarragona','Tarragona');
INSERT INTO zones VALUES (175,195,'Teruel','Teruel');
INSERT INTO zones VALUES (176,195,'Toledo','Toledo');
INSERT INTO zones VALUES (177,195,'Valencia','Valencia');
INSERT INTO zones VALUES (178,195,'Valladolid','Valladolid');
INSERT INTO zones VALUES (179,195,'Vizcaya','Vizcaya');
INSERT INTO zones VALUES (180,195,'Zamora','Zamora');
INSERT INTO zones VALUES (181,195,'Zaragoza','Zaragoza');

INSERT INTO zones VALUES (195,13,'WA','Western Australia');
INSERT INTO zones VALUES (192,13,'VIC','Victoria');
INSERT INTO zones VALUES (193,13,'QLD','Queensland');
INSERT INTO zones VALUES (191,13,'NSW','New South Wales');
INSERT INTO zones VALUES (194,13,'NT','Northern Territory');
INSERT INTO zones VALUES (196,13,'SA','South Australia');
INSERT INTO zones VALUES (197,13,'TAS','Tasmania');
INSERT INTO zones VALUES (198,13,'ACT','Australian Capital Territory');

INSERT INTO zones_to_geo_zones VALUES (1,1,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (2,2,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (3,3,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (4,4,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (5,5,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (6,6,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (7,7,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (8,8,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (9,9,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (10,10,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (11,11,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (12,12,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (13,223,NULL,1,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (14,14,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (15,15,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (16,16,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (17,17,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (18,18,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (19,19,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (20,20,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (21,21,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (22,22,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (23,23,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (24,24,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (25,25,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (26,26,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (27,27,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (28,28,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (29,29,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (30,30,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (31,31,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (32,32,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (33,33,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (34,34,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (35,35,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (36,36,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (37,37,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (38,38,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (39,39,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (40,40,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (41,41,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (42,42,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (43,43,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (44,44,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (45,45,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (46,46,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (47,47,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (48,48,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (49,49,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (50,50,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (51,51,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (52,52,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (53,53,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (54,54,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (55,55,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (56,56,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (57,57,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (58,58,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (59,59,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (60,60,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (61,61,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (62,62,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (63,63,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (64,64,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (65,65,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (66,66,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (67,67,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (68,68,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (69,69,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (70,70,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (71,71,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (72,72,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (73,73,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (74,74,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (75,75,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (76,76,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (77,77,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (78,78,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (79,79,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (80,80,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (81,81,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (82,82,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (83,83,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (84,84,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (85,85,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (86,86,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (87,87,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (88,88,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (89,89,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (90,90,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (91,91,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (92,92,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (93,93,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (94,94,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (95,95,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (96,96,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (97,97,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (98,98,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (99,99,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (100,100,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (101,101,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (102,102,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (103,103,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (104,104,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (105,105,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (106,106,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (107,107,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (108,108,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (109,109,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (110,110,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (111,111,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (112,112,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (113,113,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (114,114,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (115,115,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (116,116,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (117,117,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (118,118,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (119,119,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (120,120,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (121,121,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (122,122,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (123,123,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (124,124,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (125,125,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (126,126,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (127,127,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (128,128,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (129,129,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (130,130,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (131,131,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (132,132,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (133,133,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (134,134,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (135,135,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (136,136,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (137,137,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (138,138,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (139,139,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (140,140,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (141,141,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (142,142,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (143,143,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (144,144,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (145,145,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (146,146,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (147,147,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (148,148,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (149,149,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (150,150,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (151,151,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (152,152,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (153,153,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (154,154,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (155,155,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (156,156,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (157,157,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (158,158,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (159,159,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (160,160,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (161,161,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (162,162,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (163,163,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (164,164,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (165,165,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (166,166,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (167,167,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (168,168,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (169,169,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (170,170,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (171,171,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (172,172,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (173,173,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (174,174,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (175,175,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (176,176,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (177,177,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (178,178,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (179,179,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (180,180,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (181,181,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (182,182,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (183,183,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (184,184,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (185,185,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (186,186,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (187,187,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (188,188,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (189,189,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (190,190,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (191,191,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (192,192,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (193,193,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (194,194,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (195,195,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (196,196,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (197,197,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (198,198,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (199,199,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (200,200,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (201,201,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (202,202,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (203,203,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (204,204,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (205,205,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (206,206,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (207,207,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (208,208,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (209,209,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (210,210,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (211,211,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (212,212,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (213,213,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (214,214,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (215,215,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (216,216,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (217,217,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (218,218,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (219,219,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (220,220,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (221,221,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (222,222,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (223,223,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (224,224,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (225,225,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (226,226,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (227,227,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (228,228,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (229,229,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (230,230,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (231,231,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (232,232,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (233,233,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (234,234,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (235,235,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (236,236,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (237,237,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (238,238,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (239,239,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (240,13,NULL,2,'0000-00-00 00:00:00','0000-00-00 00:00:00');
INSERT INTO zones_to_geo_zones VALUES (241,13,NULL,3,'0000-00-00 00:00:00','0000-00-00 00:00:00');
